'''_945.py

CylindricalGearAbstractRackFlank
'''


from typing import List

from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy.gears.gear_designs.cylindrical import (
    _950, _977, _944, _946,
    _960, _1012
)
from mastapy._internal.cast_exception import CastException
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_ABSTRACT_RACK_FLANK = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical', 'CylindricalGearAbstractRackFlank')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearAbstractRackFlank',)


class CylindricalGearAbstractRackFlank(_0.APIBase):
    '''CylindricalGearAbstractRackFlank

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_ABSTRACT_RACK_FLANK

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearAbstractRackFlank.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def residual_fillet_undercut(self) -> 'float':
        '''float: 'ResidualFilletUndercut' is the original name of this property.'''

        return self.wrapped.ResidualFilletUndercut

    @residual_fillet_undercut.setter
    def residual_fillet_undercut(self, value: 'float'):
        self.wrapped.ResidualFilletUndercut = float(value) if value else 0.0

    @property
    def rough_protuberance(self) -> 'float':
        '''float: 'RoughProtuberance' is the original name of this property.'''

        return self.wrapped.RoughProtuberance

    @rough_protuberance.setter
    def rough_protuberance(self, value: 'float'):
        self.wrapped.RoughProtuberance = float(value) if value else 0.0

    @property
    def residual_fillet_undercut_factor(self) -> 'float':
        '''float: 'ResidualFilletUndercutFactor' is the original name of this property.'''

        return self.wrapped.ResidualFilletUndercutFactor

    @residual_fillet_undercut_factor.setter
    def residual_fillet_undercut_factor(self, value: 'float'):
        self.wrapped.ResidualFilletUndercutFactor = float(value) if value else 0.0

    @property
    def rough_protuberance_factor(self) -> 'float':
        '''float: 'RoughProtuberanceFactor' is the original name of this property.'''

        return self.wrapped.RoughProtuberanceFactor

    @rough_protuberance_factor.setter
    def rough_protuberance_factor(self, value: 'float'):
        self.wrapped.RoughProtuberanceFactor = float(value) if value else 0.0

    @property
    def edge_radius_factor(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'EdgeRadiusFactor' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.EdgeRadiusFactor) if self.wrapped.EdgeRadiusFactor else None

    @edge_radius_factor.setter
    def edge_radius_factor(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.EdgeRadiusFactor = value

    @property
    def protuberance_specification(self) -> 'CylindricalGearAbstractRackFlank.ProtuberanceSpecificationMethod':
        '''ProtuberanceSpecificationMethod: 'ProtuberanceSpecification' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.ProtuberanceSpecification)
        return constructor.new(CylindricalGearAbstractRackFlank.ProtuberanceSpecificationMethod)(value) if value else None

    @protuberance_specification.setter
    def protuberance_specification(self, value: 'CylindricalGearAbstractRackFlank.ProtuberanceSpecificationMethod'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.ProtuberanceSpecification = value

    @property
    def protuberance_height_factor(self) -> 'float':
        '''float: 'ProtuberanceHeightFactor' is the original name of this property.'''

        return self.wrapped.ProtuberanceHeightFactor

    @protuberance_height_factor.setter
    def protuberance_height_factor(self, value: 'float'):
        self.wrapped.ProtuberanceHeightFactor = float(value) if value else 0.0

    @property
    def protuberance_height(self) -> 'float':
        '''float: 'ProtuberanceHeight' is the original name of this property.'''

        return self.wrapped.ProtuberanceHeight

    @protuberance_height.setter
    def protuberance_height(self, value: 'float'):
        self.wrapped.ProtuberanceHeight = float(value) if value else 0.0

    @property
    def protuberance_angle(self) -> 'float':
        '''float: 'ProtuberanceAngle' is the original name of this property.'''

        return self.wrapped.ProtuberanceAngle

    @protuberance_angle.setter
    def protuberance_angle(self, value: 'float'):
        self.wrapped.ProtuberanceAngle = float(value) if value else 0.0

    @property
    def rack_undercut_clearance_normal_module(self) -> 'float':
        '''float: 'RackUndercutClearanceNormalModule' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RackUndercutClearanceNormalModule

    @property
    def rack_undercut_clearance(self) -> 'float':
        '''float: 'RackUndercutClearance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RackUndercutClearance

    @property
    def name(self) -> 'str':
        '''str: 'Name' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Name

    @property
    def radial_chamfer_height_factor(self) -> 'float':
        '''float: 'RadialChamferHeightFactor' is the original name of this property.'''

        return self.wrapped.RadialChamferHeightFactor

    @radial_chamfer_height_factor.setter
    def radial_chamfer_height_factor(self, value: 'float'):
        self.wrapped.RadialChamferHeightFactor = float(value) if value else 0.0

    @property
    def radial_chamfer_height(self) -> 'float':
        '''float: 'RadialChamferHeight' is the original name of this property.'''

        return self.wrapped.RadialChamferHeight

    @radial_chamfer_height.setter
    def radial_chamfer_height(self, value: 'float'):
        self.wrapped.RadialChamferHeight = float(value) if value else 0.0

    @property
    def diameter_chamfer_height(self) -> 'float':
        '''float: 'DiameterChamferHeight' is the original name of this property.'''

        return self.wrapped.DiameterChamferHeight

    @diameter_chamfer_height.setter
    def diameter_chamfer_height(self, value: 'float'):
        self.wrapped.DiameterChamferHeight = float(value) if value else 0.0

    @property
    def chamfer_angle(self) -> 'float':
        '''float: 'ChamferAngle' is the original name of this property.'''

        return self.wrapped.ChamferAngle

    @chamfer_angle.setter
    def chamfer_angle(self, value: 'float'):
        self.wrapped.ChamferAngle = float(value) if value else 0.0

    @property
    def chamfer_angle_in_transverse_plane(self) -> 'float':
        '''float: 'ChamferAngleInTransversePlane' is the original name of this property.'''

        return self.wrapped.ChamferAngleInTransversePlane

    @chamfer_angle_in_transverse_plane.setter
    def chamfer_angle_in_transverse_plane(self, value: 'float'):
        self.wrapped.ChamferAngleInTransversePlane = float(value) if value else 0.0

    @property
    def edge_radius(self) -> 'float':
        '''float: 'EdgeRadius' is the original name of this property.'''

        return self.wrapped.EdgeRadius

    @edge_radius.setter
    def edge_radius(self, value: 'float'):
        self.wrapped.EdgeRadius = float(value) if value else 0.0

    @property
    def gear(self) -> '_950.CylindricalGearDesign':
        '''CylindricalGearDesign: 'Gear' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _950.CylindricalGearDesign.TYPE not in self.wrapped.Gear.__class__.__mro__:
            raise CastException('Failed to cast gear to CylindricalGearDesign. Expected: {}.'.format(self.wrapped.Gear.__class__.__qualname__))

        return constructor.new_override(self.wrapped.Gear.__class__)(self.wrapped.Gear) if self.wrapped.Gear else None

    @property
    def cutter(self) -> '_944.CylindricalGearAbstractRack':
        '''CylindricalGearAbstractRack: 'Cutter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _944.CylindricalGearAbstractRack.TYPE not in self.wrapped.Cutter.__class__.__mro__:
            raise CastException('Failed to cast cutter to CylindricalGearAbstractRack. Expected: {}.'.format(self.wrapped.Cutter.__class__.__qualname__))

        return constructor.new_override(self.wrapped.Cutter.__class__)(self.wrapped.Cutter) if self.wrapped.Cutter else None

    @property
    def cutter_of_type_cylindrical_gear_basic_rack(self) -> '_946.CylindricalGearBasicRack':
        '''CylindricalGearBasicRack: 'Cutter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _946.CylindricalGearBasicRack.TYPE not in self.wrapped.Cutter.__class__.__mro__:
            raise CastException('Failed to cast cutter to CylindricalGearBasicRack. Expected: {}.'.format(self.wrapped.Cutter.__class__.__qualname__))

        return constructor.new_override(self.wrapped.Cutter.__class__)(self.wrapped.Cutter) if self.wrapped.Cutter else None

    @property
    def cutter_of_type_cylindrical_gear_pinion_type_cutter(self) -> '_960.CylindricalGearPinionTypeCutter':
        '''CylindricalGearPinionTypeCutter: 'Cutter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _960.CylindricalGearPinionTypeCutter.TYPE not in self.wrapped.Cutter.__class__.__mro__:
            raise CastException('Failed to cast cutter to CylindricalGearPinionTypeCutter. Expected: {}.'.format(self.wrapped.Cutter.__class__.__qualname__))

        return constructor.new_override(self.wrapped.Cutter.__class__)(self.wrapped.Cutter) if self.wrapped.Cutter else None

    @property
    def cutter_of_type_standard_rack(self) -> '_1012.StandardRack':
        '''StandardRack: 'Cutter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1012.StandardRack.TYPE not in self.wrapped.Cutter.__class__.__mro__:
            raise CastException('Failed to cast cutter to StandardRack. Expected: {}.'.format(self.wrapped.Cutter.__class__.__qualname__))

        return constructor.new_override(self.wrapped.Cutter.__class__)(self.wrapped.Cutter) if self.wrapped.Cutter else None

    @property
    def report_names(self) -> 'List[str]':
        '''List[str]: 'ReportNames' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ReportNames, str)
        return value

    def output_default_report_to(self, file_path: 'str'):
        ''' 'OutputDefaultReportTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else None)

    def get_default_report_with_encoded_images(self) -> 'str':
        ''' 'GetDefaultReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        '''

        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    def output_active_report_to(self, file_path: 'str'):
        ''' 'OutputActiveReportTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else None)

    def output_active_report_as_text_to(self, file_path: 'str'):
        ''' 'OutputActiveReportAsTextTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else None)

    def get_active_report_with_encoded_images(self) -> 'str':
        ''' 'GetActiveReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        '''

        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    def output_named_report_to(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(report_name if report_name else None, file_path if file_path else None)

    def output_named_report_as_masta_report(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportAsMastaReport' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(report_name if report_name else None, file_path if file_path else None)

    def output_named_report_as_text_to(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportAsTextTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(report_name if report_name else None, file_path if file_path else None)

    def get_named_report_with_encoded_images(self, report_name: 'str') -> 'str':
        ''' 'GetNamedReportWithEncodedImages' is the original name of this method.

        Args:
            report_name (str)

        Returns:
            str
        '''

        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(report_name if report_name else None)
        return method_result



'''_5328.py

StraightBevelDiffGearSetCompoundMultibodyDynamicsAnalysis
'''


from typing import List

from mastapy.system_model.part_model.gears import _2253
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.mbd_analyses.compound import _5326, _5327, _5239
from mastapy.system_model.analyses_and_results.mbd_analyses import _5190
from mastapy._internal.python_net import python_net_import

_STRAIGHT_BEVEL_DIFF_GEAR_SET_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses.Compound', 'StraightBevelDiffGearSetCompoundMultibodyDynamicsAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('StraightBevelDiffGearSetCompoundMultibodyDynamicsAnalysis',)


class StraightBevelDiffGearSetCompoundMultibodyDynamicsAnalysis(_5239.BevelGearSetCompoundMultibodyDynamicsAnalysis):
    '''StraightBevelDiffGearSetCompoundMultibodyDynamicsAnalysis

    This is a mastapy class.
    '''

    TYPE = _STRAIGHT_BEVEL_DIFF_GEAR_SET_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'StraightBevelDiffGearSetCompoundMultibodyDynamicsAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2253.StraightBevelDiffGearSet':
        '''StraightBevelDiffGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2253.StraightBevelDiffGearSet)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2253.StraightBevelDiffGearSet':
        '''StraightBevelDiffGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2253.StraightBevelDiffGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def straight_bevel_diff_gears_compound_multibody_dynamics_analysis(self) -> 'List[_5326.StraightBevelDiffGearCompoundMultibodyDynamicsAnalysis]':
        '''List[StraightBevelDiffGearCompoundMultibodyDynamicsAnalysis]: 'StraightBevelDiffGearsCompoundMultibodyDynamicsAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.StraightBevelDiffGearsCompoundMultibodyDynamicsAnalysis, constructor.new(_5326.StraightBevelDiffGearCompoundMultibodyDynamicsAnalysis))
        return value

    @property
    def straight_bevel_diff_meshes_compound_multibody_dynamics_analysis(self) -> 'List[_5327.StraightBevelDiffGearMeshCompoundMultibodyDynamicsAnalysis]':
        '''List[StraightBevelDiffGearMeshCompoundMultibodyDynamicsAnalysis]: 'StraightBevelDiffMeshesCompoundMultibodyDynamicsAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.StraightBevelDiffMeshesCompoundMultibodyDynamicsAnalysis, constructor.new(_5327.StraightBevelDiffGearMeshCompoundMultibodyDynamicsAnalysis))
        return value

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_5190.StraightBevelDiffGearSetMultibodyDynamicsAnalysis]':
        '''List[StraightBevelDiffGearSetMultibodyDynamicsAnalysis]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCasesReady, constructor.new(_5190.StraightBevelDiffGearSetMultibodyDynamicsAnalysis))
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_5190.StraightBevelDiffGearSetMultibodyDynamicsAnalysis]':
        '''List[StraightBevelDiffGearSetMultibodyDynamicsAnalysis]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCases, constructor.new(_5190.StraightBevelDiffGearSetMultibodyDynamicsAnalysis))
        return value



'''_5362.py

SystemOptimiserTargets
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_SYSTEM_OPTIMISER_TARGETS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.LoadCaseGroups', 'SystemOptimiserTargets')


__docformat__ = 'restructuredtext en'
__all__ = ('SystemOptimiserTargets',)


class SystemOptimiserTargets(Enum):
    '''SystemOptimiserTargets

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _SYSTEM_OPTIMISER_TARGETS

    __hash__ = None

    MINIMUM_FACE_WIDTH = 0
    MINIMUM_MASS = 1
    MINIMUM_WIDEST_FACE_WIDTH = 2
    CONTACT_RATIO_FIXED_FACE_WIDTH = 3


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


SystemOptimiserTargets.__setattr__ = __enum_setattr
SystemOptimiserTargets.__delattr__ = __enum_delattr



'''_859.py

MicroGeometryDesignSpaceSearchChartInformation
'''


from mastapy.gears.gear_set_pareto_optimiser import (
    _857, _860, _845, _858
)
from mastapy._internal import constructor
from mastapy._internal.cast_exception import CastException
from mastapy.gears.ltca.cylindrical import _801
from mastapy._internal.python_net import python_net_import

_MICRO_GEOMETRY_DESIGN_SPACE_SEARCH_CHART_INFORMATION = python_net_import('SMT.MastaAPI.Gears.GearSetParetoOptimiser', 'MicroGeometryDesignSpaceSearchChartInformation')


__docformat__ = 'restructuredtext en'
__all__ = ('MicroGeometryDesignSpaceSearchChartInformation',)


class MicroGeometryDesignSpaceSearchChartInformation(_845.ChartInfoBase['_801.CylindricalGearSetLoadDistributionAnalysis', '_858.MicroGeometryDesignSpaceSearchCandidate']):
    '''MicroGeometryDesignSpaceSearchChartInformation

    This is a mastapy class.
    '''

    TYPE = _MICRO_GEOMETRY_DESIGN_SPACE_SEARCH_CHART_INFORMATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'MicroGeometryDesignSpaceSearchChartInformation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def optimiser(self) -> '_857.MicroGeometryDesignSpaceSearch':
        '''MicroGeometryDesignSpaceSearch: 'Optimiser' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _857.MicroGeometryDesignSpaceSearch.TYPE not in self.wrapped.Optimiser.__class__.__mro__:
            raise CastException('Failed to cast optimiser to MicroGeometryDesignSpaceSearch. Expected: {}.'.format(self.wrapped.Optimiser.__class__.__qualname__))

        return constructor.new_override(self.wrapped.Optimiser.__class__)(self.wrapped.Optimiser) if self.wrapped.Optimiser else None

    @property
    def optimiser_of_type_micro_geometry_gear_set_design_space_search(self) -> '_860.MicroGeometryGearSetDesignSpaceSearch':
        '''MicroGeometryGearSetDesignSpaceSearch: 'Optimiser' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _860.MicroGeometryGearSetDesignSpaceSearch.TYPE not in self.wrapped.Optimiser.__class__.__mro__:
            raise CastException('Failed to cast optimiser to MicroGeometryGearSetDesignSpaceSearch. Expected: {}.'.format(self.wrapped.Optimiser.__class__.__qualname__))

        return constructor.new_override(self.wrapped.Optimiser.__class__)(self.wrapped.Optimiser) if self.wrapped.Optimiser else None



'''_3297.py

RollingRingSteadyStateSynchronousResponse
'''


from typing import List

from mastapy.system_model.part_model.couplings import _2303
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6632
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses import _3241
from mastapy._internal.python_net import python_net_import

_ROLLING_RING_STEADY_STATE_SYNCHRONOUS_RESPONSE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponses', 'RollingRingSteadyStateSynchronousResponse')


__docformat__ = 'restructuredtext en'
__all__ = ('RollingRingSteadyStateSynchronousResponse',)


class RollingRingSteadyStateSynchronousResponse(_3241.CouplingHalfSteadyStateSynchronousResponse):
    '''RollingRingSteadyStateSynchronousResponse

    This is a mastapy class.
    '''

    TYPE = _ROLLING_RING_STEADY_STATE_SYNCHRONOUS_RESPONSE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RollingRingSteadyStateSynchronousResponse.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2303.RollingRing':
        '''RollingRing: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2303.RollingRing)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6632.RollingRingLoadCase':
        '''RollingRingLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6632.RollingRingLoadCase)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None

    @property
    def planetaries(self) -> 'List[RollingRingSteadyStateSynchronousResponse]':
        '''List[RollingRingSteadyStateSynchronousResponse]: 'Planetaries' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Planetaries, constructor.new(RollingRingSteadyStateSynchronousResponse))
        return value



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._360 import StraightBevelDiffGearMeshRating
    from ._361 import StraightBevelDiffGearRating
    from ._362 import StraightBevelDiffGearSetRating
    from ._363 import StraightBevelDiffMeshedGearRating



'''_1663.py

RollerBearingUserSpecifiedProfile
'''


from typing import List

from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy.bearings.roller_bearing_profiles import (
    _1653, _1655, _1665, _1662
)
from mastapy._internal.python_net import python_net_import

_ROLLER_BEARING_USER_SPECIFIED_PROFILE = python_net_import('SMT.MastaAPI.Bearings.RollerBearingProfiles', 'RollerBearingUserSpecifiedProfile')


__docformat__ = 'restructuredtext en'
__all__ = ('RollerBearingUserSpecifiedProfile',)


class RollerBearingUserSpecifiedProfile(_1662.RollerBearingProfile):
    '''RollerBearingUserSpecifiedProfile

    This is a mastapy class.
    '''

    TYPE = _ROLLER_BEARING_USER_SPECIFIED_PROFILE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RollerBearingUserSpecifiedProfile.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def number_of_points(self) -> 'int':
        '''int: 'NumberOfPoints' is the original name of this property.'''

        return self.wrapped.NumberOfPoints

    @number_of_points.setter
    def number_of_points(self, value: 'int'):
        self.wrapped.NumberOfPoints = int(value) if value else 0

    @property
    def data_to_use(self) -> '_1653.ProfileDataToUse':
        '''ProfileDataToUse: 'DataToUse' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.DataToUse)
        return constructor.new(_1653.ProfileDataToUse)(value) if value else None

    @data_to_use.setter
    def data_to_use(self, value: '_1653.ProfileDataToUse'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.DataToUse = value

    @property
    def profile_to_fit(self) -> '_1655.ProfileToFit':
        '''ProfileToFit: 'ProfileToFit' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.ProfileToFit)
        return constructor.new(_1655.ProfileToFit)(value) if value else None

    @profile_to_fit.setter
    def profile_to_fit(self, value: '_1655.ProfileToFit'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.ProfileToFit = value

    @property
    def points(self) -> 'List[_1665.UserSpecifiedProfilePoint]':
        '''List[UserSpecifiedProfilePoint]: 'Points' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Points, constructor.new(_1665.UserSpecifiedProfilePoint))
        return value

    def set_to_full_range(self):
        ''' 'SetToFullRange' is the original name of this method.'''

        self.wrapped.SetToFullRange()



'''_513.py

SpiralBevelGearSingleFlankRating
'''


from mastapy._internal import constructor
from mastapy.gears.rating.conical import _495
from mastapy._internal.python_net import python_net_import

_SPIRAL_BEVEL_GEAR_SINGLE_FLANK_RATING = python_net_import('SMT.MastaAPI.Gears.Rating.Bevel.Standards', 'SpiralBevelGearSingleFlankRating')


__docformat__ = 'restructuredtext en'
__all__ = ('SpiralBevelGearSingleFlankRating',)


class SpiralBevelGearSingleFlankRating(_495.ConicalGearSingleFlankRating):
    '''SpiralBevelGearSingleFlankRating

    This is a mastapy class.
    '''

    TYPE = _SPIRAL_BEVEL_GEAR_SINGLE_FLANK_RATING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SpiralBevelGearSingleFlankRating.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def thermal_constant(self) -> 'float':
        '''float: 'ThermalConstant' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ThermalConstant

    @property
    def distance_factor(self) -> 'float':
        '''float: 'DistanceFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DistanceFactor

    @property
    def geometry_factor_j(self) -> 'float':
        '''float: 'GeometryFactorJ' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.GeometryFactorJ

    @property
    def bending_strength_geometry_factor(self) -> 'float':
        '''float: 'BendingStrengthGeometryFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BendingStrengthGeometryFactor

    @property
    def durability_factor(self) -> 'float':
        '''float: 'DurabilityFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DurabilityFactor

    @property
    def life_factor_contact(self) -> 'float':
        '''float: 'LifeFactorContact' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LifeFactorContact

    @property
    def life_factor_bending(self) -> 'float':
        '''float: 'LifeFactorBending' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LifeFactorBending

    @property
    def surface_condition_factor(self) -> 'float':
        '''float: 'SurfaceConditionFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SurfaceConditionFactor

    @property
    def damage_contact(self) -> 'float':
        '''float: 'DamageContact' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DamageContact

    @property
    def damage_bending(self) -> 'float':
        '''float: 'DamageBending' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DamageBending



'''_2335.py

DynamicModelForHarmonicAnalysis
'''


from mastapy.system_model.analyses_and_results import _2327
from mastapy._internal.python_net import python_net_import

_DYNAMIC_MODEL_FOR_HARMONIC_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults', 'DynamicModelForHarmonicAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('DynamicModelForHarmonicAnalysis',)


class DynamicModelForHarmonicAnalysis(_2327.SingleAnalysis):
    '''DynamicModelForHarmonicAnalysis

    This is a mastapy class.
    '''

    TYPE = _DYNAMIC_MODEL_FOR_HARMONIC_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'DynamicModelForHarmonicAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_1096.py

KimosBevelHypoidSingleRotationAngleResult
'''


from mastapy._internal import constructor
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_KIMOS_BEVEL_HYPOID_SINGLE_ROTATION_ANGLE_RESULT = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Conical', 'KimosBevelHypoidSingleRotationAngleResult')


__docformat__ = 'restructuredtext en'
__all__ = ('KimosBevelHypoidSingleRotationAngleResult',)


class KimosBevelHypoidSingleRotationAngleResult(_0.APIBase):
    '''KimosBevelHypoidSingleRotationAngleResult

    This is a mastapy class.
    '''

    TYPE = _KIMOS_BEVEL_HYPOID_SINGLE_ROTATION_ANGLE_RESULT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'KimosBevelHypoidSingleRotationAngleResult.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def pinion_rotation_angle(self) -> 'float':
        '''float: 'PinionRotationAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionRotationAngle

    @property
    def linear_transmission_error_unloaded(self) -> 'float':
        '''float: 'LinearTransmissionErrorUnloaded' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LinearTransmissionErrorUnloaded

    @property
    def linear_transmission_error_loaded(self) -> 'float':
        '''float: 'LinearTransmissionErrorLoaded' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LinearTransmissionErrorLoaded

    @property
    def mesh_stiffness_per_unit_face_width(self) -> 'float':
        '''float: 'MeshStiffnessPerUnitFaceWidth' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeshStiffnessPerUnitFaceWidth

    @property
    def maximum_pinion_root_stress(self) -> 'float':
        '''float: 'MaximumPinionRootStress' is the original name of this property.'''

        return self.wrapped.MaximumPinionRootStress

    @maximum_pinion_root_stress.setter
    def maximum_pinion_root_stress(self, value: 'float'):
        self.wrapped.MaximumPinionRootStress = float(value) if value else 0.0

    @property
    def maximum_wheel_root_stress(self) -> 'float':
        '''float: 'MaximumWheelRootStress' is the original name of this property.'''

        return self.wrapped.MaximumWheelRootStress

    @maximum_wheel_root_stress.setter
    def maximum_wheel_root_stress(self, value: 'float'):
        self.wrapped.MaximumWheelRootStress = float(value) if value else 0.0



'''_5081.py

BeltDriveMultibodyDynamicsAnalysis
'''


from typing import List

from mastapy.system_model.part_model.couplings import _2283, _2293
from mastapy._internal import constructor, conversion
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.static_loads import _6503, _6536
from mastapy.system_model.analyses_and_results.mbd_analyses import _5168, _5181
from mastapy._internal.python_net import python_net_import

_BELT_DRIVE_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses', 'BeltDriveMultibodyDynamicsAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('BeltDriveMultibodyDynamicsAnalysis',)


class BeltDriveMultibodyDynamicsAnalysis(_5181.SpecialisedAssemblyMultibodyDynamicsAnalysis):
    '''BeltDriveMultibodyDynamicsAnalysis

    This is a mastapy class.
    '''

    TYPE = _BELT_DRIVE_MULTIBODY_DYNAMICS_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BeltDriveMultibodyDynamicsAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2283.BeltDrive':
        '''BeltDrive: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2283.BeltDrive.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to BeltDrive. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6503.BeltDriveLoadCase':
        '''BeltDriveLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _6503.BeltDriveLoadCase.TYPE not in self.wrapped.AssemblyLoadCase.__class__.__mro__:
            raise CastException('Failed to cast assembly_load_case to BeltDriveLoadCase. Expected: {}.'.format(self.wrapped.AssemblyLoadCase.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyLoadCase.__class__)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None

    @property
    def pulleys(self) -> 'List[_5168.PulleyMultibodyDynamicsAnalysis]':
        '''List[PulleyMultibodyDynamicsAnalysis]: 'Pulleys' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Pulleys, constructor.new(_5168.PulleyMultibodyDynamicsAnalysis))
        return value



'''_1776.py

LoadedToroidalRollerBearingElement
'''


from mastapy._internal import constructor
from mastapy.bearings.bearing_results.rolling import _1747
from mastapy._internal.python_net import python_net_import

_LOADED_TOROIDAL_ROLLER_BEARING_ELEMENT = python_net_import('SMT.MastaAPI.Bearings.BearingResults.Rolling', 'LoadedToroidalRollerBearingElement')


__docformat__ = 'restructuredtext en'
__all__ = ('LoadedToroidalRollerBearingElement',)


class LoadedToroidalRollerBearingElement(_1747.LoadedRollerBearingElement):
    '''LoadedToroidalRollerBearingElement

    This is a mastapy class.
    '''

    TYPE = _LOADED_TOROIDAL_ROLLER_BEARING_ELEMENT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'LoadedToroidalRollerBearingElement.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def contact_angle(self) -> 'float':
        '''float: 'ContactAngle' is the original name of this property.'''

        return self.wrapped.ContactAngle

    @contact_angle.setter
    def contact_angle(self, value: 'float'):
        self.wrapped.ContactAngle = float(value) if value else 0.0



'''_1821.py

BallISOTS162812008Results
'''


from mastapy.bearings.bearing_results.rolling.iso_rating_results import _1825
from mastapy._internal.python_net import python_net_import

_BALL_ISOTS162812008_RESULTS = python_net_import('SMT.MastaAPI.Bearings.BearingResults.Rolling.IsoRatingResults', 'BallISOTS162812008Results')


__docformat__ = 'restructuredtext en'
__all__ = ('BallISOTS162812008Results',)


class BallISOTS162812008Results(_1825.ISOTS162812008Results):
    '''BallISOTS162812008Results

    This is a mastapy class.
    '''

    TYPE = _BALL_ISOTS162812008_RESULTS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BallISOTS162812008Results.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_1136.py

FlankDataSource
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_FLANK_DATA_SOURCE = python_net_import('SMT.MastaAPI.Gears.FEModel.Conical', 'FlankDataSource')


__docformat__ = 'restructuredtext en'
__all__ = ('FlankDataSource',)


class FlankDataSource(Enum):
    '''FlankDataSource

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _FLANK_DATA_SOURCE

    __hash__ = None

    MACRODESIGN = 0
    MANUFACTURING = 1


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


FlankDataSource.__setattr__ = __enum_setattr
FlankDataSource.__delattr__ = __enum_delattr



'''_528.py

LocationOfTipReliefEvaluation
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_LOCATION_OF_TIP_RELIEF_EVALUATION = python_net_import('SMT.MastaAPI.Gears.MicroGeometry', 'LocationOfTipReliefEvaluation')


__docformat__ = 'restructuredtext en'
__all__ = ('LocationOfTipReliefEvaluation',)


class LocationOfTipReliefEvaluation(Enum):
    '''LocationOfTipReliefEvaluation

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _LOCATION_OF_TIP_RELIEF_EVALUATION

    __hash__ = None

    TIP_FORM = 0
    UPPER_EVALUATION_LIMIT = 1
    USERSPECIFIED = 2


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


LocationOfTipReliefEvaluation.__setattr__ = __enum_setattr
LocationOfTipReliefEvaluation.__delattr__ = __enum_delattr



'''_505.py

ConceptGearSetRating
'''


from typing import List

from mastapy._internal import constructor, conversion
from mastapy.gears.gear_designs.concept import _1107
from mastapy.gears.rating.concept import _502, _503
from mastapy.gears.rating import _328
from mastapy._internal.python_net import python_net_import

_CONCEPT_GEAR_SET_RATING = python_net_import('SMT.MastaAPI.Gears.Rating.Concept', 'ConceptGearSetRating')


__docformat__ = 'restructuredtext en'
__all__ = ('ConceptGearSetRating',)


class ConceptGearSetRating(_328.GearSetRating):
    '''ConceptGearSetRating

    This is a mastapy class.
    '''

    TYPE = _CONCEPT_GEAR_SET_RATING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConceptGearSetRating.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def rating(self) -> 'str':
        '''str: 'Rating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Rating

    @property
    def concept_gear_set(self) -> '_1107.ConceptGearSetDesign':
        '''ConceptGearSetDesign: 'ConceptGearSet' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1107.ConceptGearSetDesign)(self.wrapped.ConceptGearSet) if self.wrapped.ConceptGearSet else None

    @property
    def concept_mesh_ratings(self) -> 'List[_502.ConceptGearMeshRating]':
        '''List[ConceptGearMeshRating]: 'ConceptMeshRatings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConceptMeshRatings, constructor.new(_502.ConceptGearMeshRating))
        return value

    @property
    def gear_ratings(self) -> 'List[_503.ConceptGearRating]':
        '''List[ConceptGearRating]: 'GearRatings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.GearRatings, constructor.new(_503.ConceptGearRating))
        return value

    @property
    def concept_gear_ratings(self) -> 'List[_503.ConceptGearRating]':
        '''List[ConceptGearRating]: 'ConceptGearRatings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConceptGearRatings, constructor.new(_503.ConceptGearRating))
        return value



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._468 import CylindricalGearToothFatigueFractureResults
    from ._469 import HelicalGearMicroGeometryOption
    from ._470 import ISO63361996GearSingleFlankRating
    from ._471 import ISO63361996MeshSingleFlankRating
    from ._472 import ISO63362006GearSingleFlankRating
    from ._473 import ISO63362006MeshSingleFlankRating
    from ._474 import ISO63362019GearSingleFlankRating
    from ._475 import ISO63362019MeshSingleFlankRating
    from ._476 import ISO6336AbstractGearSingleFlankRating
    from ._477 import ISO6336AbstractMeshSingleFlankRating
    from ._478 import ISO6336AbstractMetalGearSingleFlankRating
    from ._479 import ISO6336AbstractMetalMeshSingleFlankRating
    from ._480 import ISO6336MeanStressInfluenceFactor
    from ._481 import ISO6336MetalRateableMesh
    from ._482 import ISO6336RateableMesh
    from ._483 import ToothFlankFractureAnalysisContactPoint
    from ._484 import ToothFlankFractureAnalysisPoint



'''_1037.py

CylindricalGearProfileModification
'''


from mastapy._internal import constructor
from mastapy.gears.gear_designs.cylindrical import _962
from mastapy.gears.micro_geometry import _534
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_PROFILE_MODIFICATION = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical.MicroGeometry', 'CylindricalGearProfileModification')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearProfileModification',)


class CylindricalGearProfileModification(_534.ProfileModification):
    '''CylindricalGearProfileModification

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_PROFILE_MODIFICATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearProfileModification.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def pressure_angle_modification(self) -> 'float':
        '''float: 'PressureAngleModification' is the original name of this property.'''

        return self.wrapped.PressureAngleModification

    @pressure_angle_modification.setter
    def pressure_angle_modification(self, value: 'float'):
        self.wrapped.PressureAngleModification = float(value) if value else 0.0

    @property
    def start_of_linear_root_relief_roll_distance(self) -> 'float':
        '''float: 'StartOfLinearRootReliefRollDistance' is the original name of this property.'''

        return self.wrapped.StartOfLinearRootReliefRollDistance

    @start_of_linear_root_relief_roll_distance.setter
    def start_of_linear_root_relief_roll_distance(self, value: 'float'):
        self.wrapped.StartOfLinearRootReliefRollDistance = float(value) if value else 0.0

    @property
    def start_of_parabolic_root_relief_roll_distance(self) -> 'float':
        '''float: 'StartOfParabolicRootReliefRollDistance' is the original name of this property.'''

        return self.wrapped.StartOfParabolicRootReliefRollDistance

    @start_of_parabolic_root_relief_roll_distance.setter
    def start_of_parabolic_root_relief_roll_distance(self, value: 'float'):
        self.wrapped.StartOfParabolicRootReliefRollDistance = float(value) if value else 0.0

    @property
    def start_of_linear_tip_relief_roll_distance(self) -> 'float':
        '''float: 'StartOfLinearTipReliefRollDistance' is the original name of this property.'''

        return self.wrapped.StartOfLinearTipReliefRollDistance

    @start_of_linear_tip_relief_roll_distance.setter
    def start_of_linear_tip_relief_roll_distance(self, value: 'float'):
        self.wrapped.StartOfLinearTipReliefRollDistance = float(value) if value else 0.0

    @property
    def barrelling_peak_point_roll_distance(self) -> 'float':
        '''float: 'BarrellingPeakPointRollDistance' is the original name of this property.'''

        return self.wrapped.BarrellingPeakPointRollDistance

    @barrelling_peak_point_roll_distance.setter
    def barrelling_peak_point_roll_distance(self, value: 'float'):
        self.wrapped.BarrellingPeakPointRollDistance = float(value) if value else 0.0

    @property
    def evaluation_lower_limit_roll_distance(self) -> 'float':
        '''float: 'EvaluationLowerLimitRollDistance' is the original name of this property.'''

        return self.wrapped.EvaluationLowerLimitRollDistance

    @evaluation_lower_limit_roll_distance.setter
    def evaluation_lower_limit_roll_distance(self, value: 'float'):
        self.wrapped.EvaluationLowerLimitRollDistance = float(value) if value else 0.0

    @property
    def evaluation_upper_limit_roll_distance(self) -> 'float':
        '''float: 'EvaluationUpperLimitRollDistance' is the original name of this property.'''

        return self.wrapped.EvaluationUpperLimitRollDistance

    @evaluation_upper_limit_roll_distance.setter
    def evaluation_upper_limit_roll_distance(self, value: 'float'):
        self.wrapped.EvaluationUpperLimitRollDistance = float(value) if value else 0.0

    @property
    def evaluation_upper_limit_roll_distance_for_zero_tip_relief(self) -> 'float':
        '''float: 'EvaluationUpperLimitRollDistanceForZeroTipRelief' is the original name of this property.'''

        return self.wrapped.EvaluationUpperLimitRollDistanceForZeroTipRelief

    @evaluation_upper_limit_roll_distance_for_zero_tip_relief.setter
    def evaluation_upper_limit_roll_distance_for_zero_tip_relief(self, value: 'float'):
        self.wrapped.EvaluationUpperLimitRollDistanceForZeroTipRelief = float(value) if value else 0.0

    @property
    def evaluation_lower_limit_roll_distance_for_zero_root_relief(self) -> 'float':
        '''float: 'EvaluationLowerLimitRollDistanceForZeroRootRelief' is the original name of this property.'''

        return self.wrapped.EvaluationLowerLimitRollDistanceForZeroRootRelief

    @evaluation_lower_limit_roll_distance_for_zero_root_relief.setter
    def evaluation_lower_limit_roll_distance_for_zero_root_relief(self, value: 'float'):
        self.wrapped.EvaluationLowerLimitRollDistanceForZeroRootRelief = float(value) if value else 0.0

    @property
    def start_of_parabolic_tip_relief_roll_distance(self) -> 'float':
        '''float: 'StartOfParabolicTipReliefRollDistance' is the original name of this property.'''

        return self.wrapped.StartOfParabolicTipReliefRollDistance

    @start_of_parabolic_tip_relief_roll_distance.setter
    def start_of_parabolic_tip_relief_roll_distance(self, value: 'float'):
        self.wrapped.StartOfParabolicTipReliefRollDistance = float(value) if value else 0.0

    @property
    def evaluation_of_linear_tip_relief_roll_distance(self) -> 'float':
        '''float: 'EvaluationOfLinearTipReliefRollDistance' is the original name of this property.'''

        return self.wrapped.EvaluationOfLinearTipReliefRollDistance

    @evaluation_of_linear_tip_relief_roll_distance.setter
    def evaluation_of_linear_tip_relief_roll_distance(self, value: 'float'):
        self.wrapped.EvaluationOfLinearTipReliefRollDistance = float(value) if value else 0.0

    @property
    def evaluation_of_parabolic_tip_relief_roll_distance(self) -> 'float':
        '''float: 'EvaluationOfParabolicTipReliefRollDistance' is the original name of this property.'''

        return self.wrapped.EvaluationOfParabolicTipReliefRollDistance

    @evaluation_of_parabolic_tip_relief_roll_distance.setter
    def evaluation_of_parabolic_tip_relief_roll_distance(self, value: 'float'):
        self.wrapped.EvaluationOfParabolicTipReliefRollDistance = float(value) if value else 0.0

    @property
    def evaluation_of_linear_root_relief_roll_distance(self) -> 'float':
        '''float: 'EvaluationOfLinearRootReliefRollDistance' is the original name of this property.'''

        return self.wrapped.EvaluationOfLinearRootReliefRollDistance

    @evaluation_of_linear_root_relief_roll_distance.setter
    def evaluation_of_linear_root_relief_roll_distance(self, value: 'float'):
        self.wrapped.EvaluationOfLinearRootReliefRollDistance = float(value) if value else 0.0

    @property
    def evaluation_of_parabolic_root_relief_roll_distance(self) -> 'float':
        '''float: 'EvaluationOfParabolicRootReliefRollDistance' is the original name of this property.'''

        return self.wrapped.EvaluationOfParabolicRootReliefRollDistance

    @evaluation_of_parabolic_root_relief_roll_distance.setter
    def evaluation_of_parabolic_root_relief_roll_distance(self, value: 'float'):
        self.wrapped.EvaluationOfParabolicRootReliefRollDistance = float(value) if value else 0.0

    @property
    def start_of_linear_root_relief_roll_angle(self) -> 'float':
        '''float: 'StartOfLinearRootReliefRollAngle' is the original name of this property.'''

        return self.wrapped.StartOfLinearRootReliefRollAngle

    @start_of_linear_root_relief_roll_angle.setter
    def start_of_linear_root_relief_roll_angle(self, value: 'float'):
        self.wrapped.StartOfLinearRootReliefRollAngle = float(value) if value else 0.0

    @property
    def start_of_parabolic_root_relief_roll_angle(self) -> 'float':
        '''float: 'StartOfParabolicRootReliefRollAngle' is the original name of this property.'''

        return self.wrapped.StartOfParabolicRootReliefRollAngle

    @start_of_parabolic_root_relief_roll_angle.setter
    def start_of_parabolic_root_relief_roll_angle(self, value: 'float'):
        self.wrapped.StartOfParabolicRootReliefRollAngle = float(value) if value else 0.0

    @property
    def start_of_linear_tip_relief_roll_angle(self) -> 'float':
        '''float: 'StartOfLinearTipReliefRollAngle' is the original name of this property.'''

        return self.wrapped.StartOfLinearTipReliefRollAngle

    @start_of_linear_tip_relief_roll_angle.setter
    def start_of_linear_tip_relief_roll_angle(self, value: 'float'):
        self.wrapped.StartOfLinearTipReliefRollAngle = float(value) if value else 0.0

    @property
    def barrelling_peak_point_roll_angle(self) -> 'float':
        '''float: 'BarrellingPeakPointRollAngle' is the original name of this property.'''

        return self.wrapped.BarrellingPeakPointRollAngle

    @barrelling_peak_point_roll_angle.setter
    def barrelling_peak_point_roll_angle(self, value: 'float'):
        self.wrapped.BarrellingPeakPointRollAngle = float(value) if value else 0.0

    @property
    def evaluation_lower_limit_roll_angle(self) -> 'float':
        '''float: 'EvaluationLowerLimitRollAngle' is the original name of this property.'''

        return self.wrapped.EvaluationLowerLimitRollAngle

    @evaluation_lower_limit_roll_angle.setter
    def evaluation_lower_limit_roll_angle(self, value: 'float'):
        self.wrapped.EvaluationLowerLimitRollAngle = float(value) if value else 0.0

    @property
    def evaluation_upper_limit_roll_angle(self) -> 'float':
        '''float: 'EvaluationUpperLimitRollAngle' is the original name of this property.'''

        return self.wrapped.EvaluationUpperLimitRollAngle

    @evaluation_upper_limit_roll_angle.setter
    def evaluation_upper_limit_roll_angle(self, value: 'float'):
        self.wrapped.EvaluationUpperLimitRollAngle = float(value) if value else 0.0

    @property
    def evaluation_upper_limit_roll_angle_for_zero_tip_relief(self) -> 'float':
        '''float: 'EvaluationUpperLimitRollAngleForZeroTipRelief' is the original name of this property.'''

        return self.wrapped.EvaluationUpperLimitRollAngleForZeroTipRelief

    @evaluation_upper_limit_roll_angle_for_zero_tip_relief.setter
    def evaluation_upper_limit_roll_angle_for_zero_tip_relief(self, value: 'float'):
        self.wrapped.EvaluationUpperLimitRollAngleForZeroTipRelief = float(value) if value else 0.0

    @property
    def evaluation_lower_limit_roll_angle_for_zero_root_relief(self) -> 'float':
        '''float: 'EvaluationLowerLimitRollAngleForZeroRootRelief' is the original name of this property.'''

        return self.wrapped.EvaluationLowerLimitRollAngleForZeroRootRelief

    @evaluation_lower_limit_roll_angle_for_zero_root_relief.setter
    def evaluation_lower_limit_roll_angle_for_zero_root_relief(self, value: 'float'):
        self.wrapped.EvaluationLowerLimitRollAngleForZeroRootRelief = float(value) if value else 0.0

    @property
    def start_of_parabolic_tip_relief_roll_angle(self) -> 'float':
        '''float: 'StartOfParabolicTipReliefRollAngle' is the original name of this property.'''

        return self.wrapped.StartOfParabolicTipReliefRollAngle

    @start_of_parabolic_tip_relief_roll_angle.setter
    def start_of_parabolic_tip_relief_roll_angle(self, value: 'float'):
        self.wrapped.StartOfParabolicTipReliefRollAngle = float(value) if value else 0.0

    @property
    def evaluation_of_linear_tip_relief_roll_angle(self) -> 'float':
        '''float: 'EvaluationOfLinearTipReliefRollAngle' is the original name of this property.'''

        return self.wrapped.EvaluationOfLinearTipReliefRollAngle

    @evaluation_of_linear_tip_relief_roll_angle.setter
    def evaluation_of_linear_tip_relief_roll_angle(self, value: 'float'):
        self.wrapped.EvaluationOfLinearTipReliefRollAngle = float(value) if value else 0.0

    @property
    def evaluation_of_parabolic_tip_relief_roll_angle(self) -> 'float':
        '''float: 'EvaluationOfParabolicTipReliefRollAngle' is the original name of this property.'''

        return self.wrapped.EvaluationOfParabolicTipReliefRollAngle

    @evaluation_of_parabolic_tip_relief_roll_angle.setter
    def evaluation_of_parabolic_tip_relief_roll_angle(self, value: 'float'):
        self.wrapped.EvaluationOfParabolicTipReliefRollAngle = float(value) if value else 0.0

    @property
    def evaluation_of_linear_root_relief_roll_angle(self) -> 'float':
        '''float: 'EvaluationOfLinearRootReliefRollAngle' is the original name of this property.'''

        return self.wrapped.EvaluationOfLinearRootReliefRollAngle

    @evaluation_of_linear_root_relief_roll_angle.setter
    def evaluation_of_linear_root_relief_roll_angle(self, value: 'float'):
        self.wrapped.EvaluationOfLinearRootReliefRollAngle = float(value) if value else 0.0

    @property
    def evaluation_of_parabolic_root_relief_roll_angle(self) -> 'float':
        '''float: 'EvaluationOfParabolicRootReliefRollAngle' is the original name of this property.'''

        return self.wrapped.EvaluationOfParabolicRootReliefRollAngle

    @evaluation_of_parabolic_root_relief_roll_angle.setter
    def evaluation_of_parabolic_root_relief_roll_angle(self, value: 'float'):
        self.wrapped.EvaluationOfParabolicRootReliefRollAngle = float(value) if value else 0.0

    @property
    def start_of_linear_root_relief_diameter(self) -> 'float':
        '''float: 'StartOfLinearRootReliefDiameter' is the original name of this property.'''

        return self.wrapped.StartOfLinearRootReliefDiameter

    @start_of_linear_root_relief_diameter.setter
    def start_of_linear_root_relief_diameter(self, value: 'float'):
        self.wrapped.StartOfLinearRootReliefDiameter = float(value) if value else 0.0

    @property
    def start_of_parabolic_root_relief_diameter(self) -> 'float':
        '''float: 'StartOfParabolicRootReliefDiameter' is the original name of this property.'''

        return self.wrapped.StartOfParabolicRootReliefDiameter

    @start_of_parabolic_root_relief_diameter.setter
    def start_of_parabolic_root_relief_diameter(self, value: 'float'):
        self.wrapped.StartOfParabolicRootReliefDiameter = float(value) if value else 0.0

    @property
    def start_of_linear_tip_relief_diameter(self) -> 'float':
        '''float: 'StartOfLinearTipReliefDiameter' is the original name of this property.'''

        return self.wrapped.StartOfLinearTipReliefDiameter

    @start_of_linear_tip_relief_diameter.setter
    def start_of_linear_tip_relief_diameter(self, value: 'float'):
        self.wrapped.StartOfLinearTipReliefDiameter = float(value) if value else 0.0

    @property
    def barrelling_peak_point_diameter(self) -> 'float':
        '''float: 'BarrellingPeakPointDiameter' is the original name of this property.'''

        return self.wrapped.BarrellingPeakPointDiameter

    @barrelling_peak_point_diameter.setter
    def barrelling_peak_point_diameter(self, value: 'float'):
        self.wrapped.BarrellingPeakPointDiameter = float(value) if value else 0.0

    @property
    def evaluation_lower_limit_diameter(self) -> 'float':
        '''float: 'EvaluationLowerLimitDiameter' is the original name of this property.'''

        return self.wrapped.EvaluationLowerLimitDiameter

    @evaluation_lower_limit_diameter.setter
    def evaluation_lower_limit_diameter(self, value: 'float'):
        self.wrapped.EvaluationLowerLimitDiameter = float(value) if value else 0.0

    @property
    def evaluation_upper_limit_diameter(self) -> 'float':
        '''float: 'EvaluationUpperLimitDiameter' is the original name of this property.'''

        return self.wrapped.EvaluationUpperLimitDiameter

    @evaluation_upper_limit_diameter.setter
    def evaluation_upper_limit_diameter(self, value: 'float'):
        self.wrapped.EvaluationUpperLimitDiameter = float(value) if value else 0.0

    @property
    def evaluation_upper_limit_diameter_for_zero_tip_relief(self) -> 'float':
        '''float: 'EvaluationUpperLimitDiameterForZeroTipRelief' is the original name of this property.'''

        return self.wrapped.EvaluationUpperLimitDiameterForZeroTipRelief

    @evaluation_upper_limit_diameter_for_zero_tip_relief.setter
    def evaluation_upper_limit_diameter_for_zero_tip_relief(self, value: 'float'):
        self.wrapped.EvaluationUpperLimitDiameterForZeroTipRelief = float(value) if value else 0.0

    @property
    def evaluation_lower_limit_diameter_for_zero_root_relief(self) -> 'float':
        '''float: 'EvaluationLowerLimitDiameterForZeroRootRelief' is the original name of this property.'''

        return self.wrapped.EvaluationLowerLimitDiameterForZeroRootRelief

    @evaluation_lower_limit_diameter_for_zero_root_relief.setter
    def evaluation_lower_limit_diameter_for_zero_root_relief(self, value: 'float'):
        self.wrapped.EvaluationLowerLimitDiameterForZeroRootRelief = float(value) if value else 0.0

    @property
    def start_of_parabolic_tip_relief_diameter(self) -> 'float':
        '''float: 'StartOfParabolicTipReliefDiameter' is the original name of this property.'''

        return self.wrapped.StartOfParabolicTipReliefDiameter

    @start_of_parabolic_tip_relief_diameter.setter
    def start_of_parabolic_tip_relief_diameter(self, value: 'float'):
        self.wrapped.StartOfParabolicTipReliefDiameter = float(value) if value else 0.0

    @property
    def evaluation_of_linear_tip_relief_diameter(self) -> 'float':
        '''float: 'EvaluationOfLinearTipReliefDiameter' is the original name of this property.'''

        return self.wrapped.EvaluationOfLinearTipReliefDiameter

    @evaluation_of_linear_tip_relief_diameter.setter
    def evaluation_of_linear_tip_relief_diameter(self, value: 'float'):
        self.wrapped.EvaluationOfLinearTipReliefDiameter = float(value) if value else 0.0

    @property
    def evaluation_of_parabolic_tip_relief_diameter(self) -> 'float':
        '''float: 'EvaluationOfParabolicTipReliefDiameter' is the original name of this property.'''

        return self.wrapped.EvaluationOfParabolicTipReliefDiameter

    @evaluation_of_parabolic_tip_relief_diameter.setter
    def evaluation_of_parabolic_tip_relief_diameter(self, value: 'float'):
        self.wrapped.EvaluationOfParabolicTipReliefDiameter = float(value) if value else 0.0

    @property
    def evaluation_of_linear_root_relief_diameter(self) -> 'float':
        '''float: 'EvaluationOfLinearRootReliefDiameter' is the original name of this property.'''

        return self.wrapped.EvaluationOfLinearRootReliefDiameter

    @evaluation_of_linear_root_relief_diameter.setter
    def evaluation_of_linear_root_relief_diameter(self, value: 'float'):
        self.wrapped.EvaluationOfLinearRootReliefDiameter = float(value) if value else 0.0

    @property
    def evaluation_of_parabolic_root_relief_diameter(self) -> 'float':
        '''float: 'EvaluationOfParabolicRootReliefDiameter' is the original name of this property.'''

        return self.wrapped.EvaluationOfParabolicRootReliefDiameter

    @evaluation_of_parabolic_root_relief_diameter.setter
    def evaluation_of_parabolic_root_relief_diameter(self, value: 'float'):
        self.wrapped.EvaluationOfParabolicRootReliefDiameter = float(value) if value else 0.0

    @property
    def start_of_linear_root_relief_radius(self) -> 'float':
        '''float: 'StartOfLinearRootReliefRadius' is the original name of this property.'''

        return self.wrapped.StartOfLinearRootReliefRadius

    @start_of_linear_root_relief_radius.setter
    def start_of_linear_root_relief_radius(self, value: 'float'):
        self.wrapped.StartOfLinearRootReliefRadius = float(value) if value else 0.0

    @property
    def start_of_parabolic_root_relief_radius(self) -> 'float':
        '''float: 'StartOfParabolicRootReliefRadius' is the original name of this property.'''

        return self.wrapped.StartOfParabolicRootReliefRadius

    @start_of_parabolic_root_relief_radius.setter
    def start_of_parabolic_root_relief_radius(self, value: 'float'):
        self.wrapped.StartOfParabolicRootReliefRadius = float(value) if value else 0.0

    @property
    def start_of_linear_tip_relief_radius(self) -> 'float':
        '''float: 'StartOfLinearTipReliefRadius' is the original name of this property.'''

        return self.wrapped.StartOfLinearTipReliefRadius

    @start_of_linear_tip_relief_radius.setter
    def start_of_linear_tip_relief_radius(self, value: 'float'):
        self.wrapped.StartOfLinearTipReliefRadius = float(value) if value else 0.0

    @property
    def barrelling_peak_point_radius(self) -> 'float':
        '''float: 'BarrellingPeakPointRadius' is the original name of this property.'''

        return self.wrapped.BarrellingPeakPointRadius

    @barrelling_peak_point_radius.setter
    def barrelling_peak_point_radius(self, value: 'float'):
        self.wrapped.BarrellingPeakPointRadius = float(value) if value else 0.0

    @property
    def evaluation_lower_limit_radius(self) -> 'float':
        '''float: 'EvaluationLowerLimitRadius' is the original name of this property.'''

        return self.wrapped.EvaluationLowerLimitRadius

    @evaluation_lower_limit_radius.setter
    def evaluation_lower_limit_radius(self, value: 'float'):
        self.wrapped.EvaluationLowerLimitRadius = float(value) if value else 0.0

    @property
    def evaluation_upper_limit_radius(self) -> 'float':
        '''float: 'EvaluationUpperLimitRadius' is the original name of this property.'''

        return self.wrapped.EvaluationUpperLimitRadius

    @evaluation_upper_limit_radius.setter
    def evaluation_upper_limit_radius(self, value: 'float'):
        self.wrapped.EvaluationUpperLimitRadius = float(value) if value else 0.0

    @property
    def evaluation_upper_limit_radius_for_zero_tip_relief(self) -> 'float':
        '''float: 'EvaluationUpperLimitRadiusForZeroTipRelief' is the original name of this property.'''

        return self.wrapped.EvaluationUpperLimitRadiusForZeroTipRelief

    @evaluation_upper_limit_radius_for_zero_tip_relief.setter
    def evaluation_upper_limit_radius_for_zero_tip_relief(self, value: 'float'):
        self.wrapped.EvaluationUpperLimitRadiusForZeroTipRelief = float(value) if value else 0.0

    @property
    def evaluation_lower_limit_radius_for_zero_root_relief(self) -> 'float':
        '''float: 'EvaluationLowerLimitRadiusForZeroRootRelief' is the original name of this property.'''

        return self.wrapped.EvaluationLowerLimitRadiusForZeroRootRelief

    @evaluation_lower_limit_radius_for_zero_root_relief.setter
    def evaluation_lower_limit_radius_for_zero_root_relief(self, value: 'float'):
        self.wrapped.EvaluationLowerLimitRadiusForZeroRootRelief = float(value) if value else 0.0

    @property
    def start_of_parabolic_tip_relief_radius(self) -> 'float':
        '''float: 'StartOfParabolicTipReliefRadius' is the original name of this property.'''

        return self.wrapped.StartOfParabolicTipReliefRadius

    @start_of_parabolic_tip_relief_radius.setter
    def start_of_parabolic_tip_relief_radius(self, value: 'float'):
        self.wrapped.StartOfParabolicTipReliefRadius = float(value) if value else 0.0

    @property
    def evaluation_of_linear_tip_relief_radius(self) -> 'float':
        '''float: 'EvaluationOfLinearTipReliefRadius' is the original name of this property.'''

        return self.wrapped.EvaluationOfLinearTipReliefRadius

    @evaluation_of_linear_tip_relief_radius.setter
    def evaluation_of_linear_tip_relief_radius(self, value: 'float'):
        self.wrapped.EvaluationOfLinearTipReliefRadius = float(value) if value else 0.0

    @property
    def evaluation_of_parabolic_tip_relief_radius(self) -> 'float':
        '''float: 'EvaluationOfParabolicTipReliefRadius' is the original name of this property.'''

        return self.wrapped.EvaluationOfParabolicTipReliefRadius

    @evaluation_of_parabolic_tip_relief_radius.setter
    def evaluation_of_parabolic_tip_relief_radius(self, value: 'float'):
        self.wrapped.EvaluationOfParabolicTipReliefRadius = float(value) if value else 0.0

    @property
    def evaluation_of_linear_root_relief_radius(self) -> 'float':
        '''float: 'EvaluationOfLinearRootReliefRadius' is the original name of this property.'''

        return self.wrapped.EvaluationOfLinearRootReliefRadius

    @evaluation_of_linear_root_relief_radius.setter
    def evaluation_of_linear_root_relief_radius(self, value: 'float'):
        self.wrapped.EvaluationOfLinearRootReliefRadius = float(value) if value else 0.0

    @property
    def evaluation_of_parabolic_root_relief_radius(self) -> 'float':
        '''float: 'EvaluationOfParabolicRootReliefRadius' is the original name of this property.'''

        return self.wrapped.EvaluationOfParabolicRootReliefRadius

    @evaluation_of_parabolic_root_relief_radius.setter
    def evaluation_of_parabolic_root_relief_radius(self, value: 'float'):
        self.wrapped.EvaluationOfParabolicRootReliefRadius = float(value) if value else 0.0

    @property
    def linear_relief_ldp(self) -> 'float':
        '''float: 'LinearReliefLDP' is the original name of this property.'''

        return self.wrapped.LinearReliefLDP

    @linear_relief_ldp.setter
    def linear_relief_ldp(self, value: 'float'):
        self.wrapped.LinearReliefLDP = float(value) if value else 0.0

    @property
    def linear_relief_isoagmadin(self) -> 'float':
        '''float: 'LinearReliefISOAGMADIN' is the original name of this property.'''

        return self.wrapped.LinearReliefISOAGMADIN

    @linear_relief_isoagmadin.setter
    def linear_relief_isoagmadin(self, value: 'float'):
        self.wrapped.LinearReliefISOAGMADIN = float(value) if value else 0.0

    @property
    def linear_relief_vdi(self) -> 'float':
        '''float: 'LinearReliefVDI' is the original name of this property.'''

        return self.wrapped.LinearReliefVDI

    @linear_relief_vdi.setter
    def linear_relief_vdi(self, value: 'float'):
        self.wrapped.LinearReliefVDI = float(value) if value else 0.0

    @property
    def linear_root_relief_start(self) -> '_962.CylindricalGearProfileMeasurement':
        '''CylindricalGearProfileMeasurement: 'LinearRootReliefStart' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_962.CylindricalGearProfileMeasurement)(self.wrapped.LinearRootReliefStart) if self.wrapped.LinearRootReliefStart else None

    @property
    def parabolic_root_relief_start(self) -> '_962.CylindricalGearProfileMeasurement':
        '''CylindricalGearProfileMeasurement: 'ParabolicRootReliefStart' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_962.CylindricalGearProfileMeasurement)(self.wrapped.ParabolicRootReliefStart) if self.wrapped.ParabolicRootReliefStart else None

    @property
    def linear_tip_relief_start(self) -> '_962.CylindricalGearProfileMeasurement':
        '''CylindricalGearProfileMeasurement: 'LinearTipReliefStart' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_962.CylindricalGearProfileMeasurement)(self.wrapped.LinearTipReliefStart) if self.wrapped.LinearTipReliefStart else None

    @property
    def parabolic_tip_relief_start(self) -> '_962.CylindricalGearProfileMeasurement':
        '''CylindricalGearProfileMeasurement: 'ParabolicTipReliefStart' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_962.CylindricalGearProfileMeasurement)(self.wrapped.ParabolicTipReliefStart) if self.wrapped.ParabolicTipReliefStart else None

    @property
    def barrelling_peak_point(self) -> '_962.CylindricalGearProfileMeasurement':
        '''CylindricalGearProfileMeasurement: 'BarrellingPeakPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_962.CylindricalGearProfileMeasurement)(self.wrapped.BarrellingPeakPoint) if self.wrapped.BarrellingPeakPoint else None

    @property
    def evaluation_lower_limit(self) -> '_962.CylindricalGearProfileMeasurement':
        '''CylindricalGearProfileMeasurement: 'EvaluationLowerLimit' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_962.CylindricalGearProfileMeasurement)(self.wrapped.EvaluationLowerLimit) if self.wrapped.EvaluationLowerLimit else None

    @property
    def evaluation_upper_limit(self) -> '_962.CylindricalGearProfileMeasurement':
        '''CylindricalGearProfileMeasurement: 'EvaluationUpperLimit' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_962.CylindricalGearProfileMeasurement)(self.wrapped.EvaluationUpperLimit) if self.wrapped.EvaluationUpperLimit else None

    @property
    def evaluation_upper_limit_for_zero_tip_relief(self) -> '_962.CylindricalGearProfileMeasurement':
        '''CylindricalGearProfileMeasurement: 'EvaluationUpperLimitForZeroTipRelief' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_962.CylindricalGearProfileMeasurement)(self.wrapped.EvaluationUpperLimitForZeroTipRelief) if self.wrapped.EvaluationUpperLimitForZeroTipRelief else None

    @property
    def evaluation_lower_limit_for_zero_root_relief(self) -> '_962.CylindricalGearProfileMeasurement':
        '''CylindricalGearProfileMeasurement: 'EvaluationLowerLimitForZeroRootRelief' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_962.CylindricalGearProfileMeasurement)(self.wrapped.EvaluationLowerLimitForZeroRootRelief) if self.wrapped.EvaluationLowerLimitForZeroRootRelief else None

    @property
    def linear_tip_relief_evaluation(self) -> '_962.CylindricalGearProfileMeasurement':
        '''CylindricalGearProfileMeasurement: 'LinearTipReliefEvaluation' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_962.CylindricalGearProfileMeasurement)(self.wrapped.LinearTipReliefEvaluation) if self.wrapped.LinearTipReliefEvaluation else None

    @property
    def parabolic_tip_relief_evaluation(self) -> '_962.CylindricalGearProfileMeasurement':
        '''CylindricalGearProfileMeasurement: 'ParabolicTipReliefEvaluation' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_962.CylindricalGearProfileMeasurement)(self.wrapped.ParabolicTipReliefEvaluation) if self.wrapped.ParabolicTipReliefEvaluation else None

    @property
    def linear_root_relief_evaluation(self) -> '_962.CylindricalGearProfileMeasurement':
        '''CylindricalGearProfileMeasurement: 'LinearRootReliefEvaluation' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_962.CylindricalGearProfileMeasurement)(self.wrapped.LinearRootReliefEvaluation) if self.wrapped.LinearRootReliefEvaluation else None

    @property
    def parabolic_root_relief_evaluation(self) -> '_962.CylindricalGearProfileMeasurement':
        '''CylindricalGearProfileMeasurement: 'ParabolicRootReliefEvaluation' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_962.CylindricalGearProfileMeasurement)(self.wrapped.ParabolicRootReliefEvaluation) if self.wrapped.ParabolicRootReliefEvaluation else None

    def relief_of(self, roll_distance: 'float') -> 'float':
        ''' 'ReliefOf' is the original name of this method.

        Args:
            roll_distance (float)

        Returns:
            float
        '''

        roll_distance = float(roll_distance)
        method_result = self.wrapped.ReliefOf(roll_distance if roll_distance else 0.0)
        return method_result



'''_1230.py

Table4JointInterfaceTypes
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_TABLE_4_JOINT_INTERFACE_TYPES = python_net_import('SMT.MastaAPI.DetailedRigidConnectors.InterferenceFits', 'Table4JointInterfaceTypes')


__docformat__ = 'restructuredtext en'
__all__ = ('Table4JointInterfaceTypes',)


class Table4JointInterfaceTypes(Enum):
    '''Table4JointInterfaceTypes

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _TABLE_4_JOINT_INTERFACE_TYPES

    __hash__ = None

    STEELSTEEL_INTERFACE_JOINED_WITH_MINERAL_OIL = 0
    STEELSTEEL_INTERFACE_JOINED_WITH_OIL_AND_DEGREASED_SURFACES_GLYCERINE = 1
    STEELSTEEL_INTERFACE_JOINED_WITH_THERMAL_EXPANSION = 2
    STEELSTEEL_INTERFACE_JOINED_WITH_THERMAL_EXPANSION_AND_DEGREASED_SURFACES = 3
    STEELIRON_INTERFACE_JOINED_WITH_MINERAL_OIL = 4
    STEELIRON_INTERFACE_JOINED_WITH_OIL_AND_DEGREASED_SURFACES = 5
    STEELMGAL_INTERFACE_DRY = 6
    STEELCUZN_INTERFACE_DRY = 7


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


Table4JointInterfaceTypes.__setattr__ = __enum_setattr
Table4JointInterfaceTypes.__delattr__ = __enum_delattr



'''_4005.py

BevelDifferentialGearMeshParametricStudyTool
'''


from typing import List

from mastapy.system_model.connections_and_sockets.gears import _2010
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6505
from mastapy.system_model.analyses_and_results.system_deflections import _2403
from mastapy.system_model.analyses_and_results.parametric_study_tools import _4010
from mastapy._internal.python_net import python_net_import

_BEVEL_DIFFERENTIAL_GEAR_MESH_PARAMETRIC_STUDY_TOOL = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ParametricStudyTools', 'BevelDifferentialGearMeshParametricStudyTool')


__docformat__ = 'restructuredtext en'
__all__ = ('BevelDifferentialGearMeshParametricStudyTool',)


class BevelDifferentialGearMeshParametricStudyTool(_4010.BevelGearMeshParametricStudyTool):
    '''BevelDifferentialGearMeshParametricStudyTool

    This is a mastapy class.
    '''

    TYPE = _BEVEL_DIFFERENTIAL_GEAR_MESH_PARAMETRIC_STUDY_TOOL

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BevelDifferentialGearMeshParametricStudyTool.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_design(self) -> '_2010.BevelDifferentialGearMesh':
        '''BevelDifferentialGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2010.BevelDifferentialGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_load_case(self) -> '_6505.BevelDifferentialGearMeshLoadCase':
        '''BevelDifferentialGearMeshLoadCase: 'ConnectionLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6505.BevelDifferentialGearMeshLoadCase)(self.wrapped.ConnectionLoadCase) if self.wrapped.ConnectionLoadCase else None

    @property
    def connection_system_deflection_results(self) -> 'List[_2403.BevelDifferentialGearMeshSystemDeflection]':
        '''List[BevelDifferentialGearMeshSystemDeflection]: 'ConnectionSystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConnectionSystemDeflectionResults, constructor.new(_2403.BevelDifferentialGearMeshSystemDeflection))
        return value



'''_1323.py

Optimisable
'''


from mastapy.math_utility.optimisation import _1319
from mastapy._internal.python_net import python_net_import

_OPTIMISABLE = python_net_import('SMT.MastaAPI.MathUtility.Optimisation', 'Optimisable')


__docformat__ = 'restructuredtext en'
__all__ = ('Optimisable',)


class Optimisable(_1319.AbstractOptimisable):
    '''Optimisable

    This is a mastapy class.
    '''

    TYPE = _OPTIMISABLE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'Optimisable.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_3364.py

ConceptCouplingHalfCompoundSteadyStateSynchronousResponse
'''


from typing import List

from mastapy.system_model.part_model.couplings import _2289
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses import _3230
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses.compound import _3375
from mastapy._internal.python_net import python_net_import

_CONCEPT_COUPLING_HALF_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponses.Compound', 'ConceptCouplingHalfCompoundSteadyStateSynchronousResponse')


__docformat__ = 'restructuredtext en'
__all__ = ('ConceptCouplingHalfCompoundSteadyStateSynchronousResponse',)


class ConceptCouplingHalfCompoundSteadyStateSynchronousResponse(_3375.CouplingHalfCompoundSteadyStateSynchronousResponse):
    '''ConceptCouplingHalfCompoundSteadyStateSynchronousResponse

    This is a mastapy class.
    '''

    TYPE = _CONCEPT_COUPLING_HALF_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConceptCouplingHalfCompoundSteadyStateSynchronousResponse.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2289.ConceptCouplingHalf':
        '''ConceptCouplingHalf: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2289.ConceptCouplingHalf)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_analysis_cases_ready(self) -> 'List[_3230.ConceptCouplingHalfSteadyStateSynchronousResponse]':
        '''List[ConceptCouplingHalfSteadyStateSynchronousResponse]: 'ComponentAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCasesReady, constructor.new(_3230.ConceptCouplingHalfSteadyStateSynchronousResponse))
        return value

    @property
    def component_analysis_cases(self) -> 'List[_3230.ConceptCouplingHalfSteadyStateSynchronousResponse]':
        '''List[ConceptCouplingHalfSteadyStateSynchronousResponse]: 'ComponentAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCases, constructor.new(_3230.ConceptCouplingHalfSteadyStateSynchronousResponse))
        return value



'''_2058.py

PartToPartShearCouplingSocket
'''


from mastapy.system_model.connections_and_sockets.couplings import _2056
from mastapy._internal.python_net import python_net_import

_PART_TO_PART_SHEAR_COUPLING_SOCKET = python_net_import('SMT.MastaAPI.SystemModel.ConnectionsAndSockets.Couplings', 'PartToPartShearCouplingSocket')


__docformat__ = 'restructuredtext en'
__all__ = ('PartToPartShearCouplingSocket',)


class PartToPartShearCouplingSocket(_2056.CouplingSocket):
    '''PartToPartShearCouplingSocket

    This is a mastapy class.
    '''

    TYPE = _PART_TO_PART_SHEAR_COUPLING_SOCKET

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PartToPartShearCouplingSocket.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_142.py

SurfaceToSurfaceContactStiffnessEntity
'''


from mastapy.math_utility.stiffness_calculators import _1318
from mastapy._internal import constructor
from mastapy.nodal_analysis.nodal_entities import _120
from mastapy._internal.python_net import python_net_import

_SURFACE_TO_SURFACE_CONTACT_STIFFNESS_ENTITY = python_net_import('SMT.MastaAPI.NodalAnalysis.NodalEntities', 'SurfaceToSurfaceContactStiffnessEntity')


__docformat__ = 'restructuredtext en'
__all__ = ('SurfaceToSurfaceContactStiffnessEntity',)


class SurfaceToSurfaceContactStiffnessEntity(_120.ArbitraryNodalComponent):
    '''SurfaceToSurfaceContactStiffnessEntity

    This is a mastapy class.
    '''

    TYPE = _SURFACE_TO_SURFACE_CONTACT_STIFFNESS_ENTITY

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SurfaceToSurfaceContactStiffnessEntity.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def contact(self) -> '_1318.SurfaceToSurfaceContact':
        '''SurfaceToSurfaceContact: 'Contact' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1318.SurfaceToSurfaceContact)(self.wrapped.Contact) if self.wrapped.Contact else None



'''_4085.py

ParametricStudyStaticLoad
'''


from mastapy.system_model.analyses_and_results.static_loads import _6486
from mastapy._internal.python_net import python_net_import

_PARAMETRIC_STUDY_STATIC_LOAD = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ParametricStudyTools', 'ParametricStudyStaticLoad')


__docformat__ = 'restructuredtext en'
__all__ = ('ParametricStudyStaticLoad',)


class ParametricStudyStaticLoad(_6486.StaticLoadCase):
    '''ParametricStudyStaticLoad

    This is a mastapy class.
    '''

    TYPE = _PARAMETRIC_STUDY_STATIC_LOAD

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ParametricStudyStaticLoad.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_668.py

RoughCutterSimulation
'''


from mastapy.gears.manufacturing.cylindrical.cutter_simulation import _663
from mastapy._internal.python_net import python_net_import

_ROUGH_CUTTER_SIMULATION = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Cylindrical.CutterSimulation', 'RoughCutterSimulation')


__docformat__ = 'restructuredtext en'
__all__ = ('RoughCutterSimulation',)


class RoughCutterSimulation(_663.GearCutterSimulation):
    '''RoughCutterSimulation

    This is a mastapy class.
    '''

    TYPE = _ROUGH_CUTTER_SIMULATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RoughCutterSimulation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_921.py

KlingelnbergConicalGearSetDesign
'''


from typing import List

from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy.gears.gear_designs.conical import _1097, _1085
from mastapy._internal.implicit import list_with_selected_item
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy.gears.gear_designs.klingelnberg_conical import _920
from mastapy._internal.python_net import python_net_import

_KLINGELNBERG_CONICAL_GEAR_SET_DESIGN = python_net_import('SMT.MastaAPI.Gears.GearDesigns.KlingelnbergConical', 'KlingelnbergConicalGearSetDesign')


__docformat__ = 'restructuredtext en'
__all__ = ('KlingelnbergConicalGearSetDesign',)


class KlingelnbergConicalGearSetDesign(_1085.ConicalGearSetDesign):
    '''KlingelnbergConicalGearSetDesign

    This is a mastapy class.
    '''

    TYPE = _KLINGELNBERG_CONICAL_GEAR_SET_DESIGN

    __hash__ = None

    def __init__(self, instance_to_wrap: 'KlingelnbergConicalGearSetDesign.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def wheel_pitch_diameter(self) -> 'float':
        '''float: 'WheelPitchDiameter' is the original name of this property.'''

        return self.wrapped.WheelPitchDiameter

    @wheel_pitch_diameter.setter
    def wheel_pitch_diameter(self, value: 'float'):
        self.wrapped.WheelPitchDiameter = float(value) if value else 0.0

    @property
    def stub_factor(self) -> 'float':
        '''float: 'StubFactor' is the original name of this property.'''

        return self.wrapped.StubFactor

    @stub_factor.setter
    def stub_factor(self, value: 'float'):
        self.wrapped.StubFactor = float(value) if value else 0.0

    @property
    def addendum_modification_factor(self) -> 'float':
        '''float: 'AddendumModificationFactor' is the original name of this property.'''

        return self.wrapped.AddendumModificationFactor

    @addendum_modification_factor.setter
    def addendum_modification_factor(self, value: 'float'):
        self.wrapped.AddendumModificationFactor = float(value) if value else 0.0

    @property
    def tooth_thickness_modification_factor(self) -> 'float':
        '''float: 'ToothThicknessModificationFactor' is the original name of this property.'''

        return self.wrapped.ToothThicknessModificationFactor

    @tooth_thickness_modification_factor.setter
    def tooth_thickness_modification_factor(self, value: 'float'):
        self.wrapped.ToothThicknessModificationFactor = float(value) if value else 0.0

    @property
    def angle_modification(self) -> 'float':
        '''float: 'AngleModification' is the original name of this property.'''

        return self.wrapped.AngleModification

    @angle_modification.setter
    def angle_modification(self, value: 'float'):
        self.wrapped.AngleModification = float(value) if value else 0.0

    @property
    def shaft_angle(self) -> 'float':
        '''float: 'ShaftAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ShaftAngle

    @property
    def pinion_number_of_teeth(self) -> 'int':
        '''int: 'PinionNumberOfTeeth' is the original name of this property.'''

        return self.wrapped.PinionNumberOfTeeth

    @pinion_number_of_teeth.setter
    def pinion_number_of_teeth(self, value: 'int'):
        self.wrapped.PinionNumberOfTeeth = int(value) if value else 0

    @property
    def wheel_number_of_teeth(self) -> 'int':
        '''int: 'WheelNumberOfTeeth' is the original name of this property.'''

        return self.wrapped.WheelNumberOfTeeth

    @wheel_number_of_teeth.setter
    def wheel_number_of_teeth(self, value: 'int'):
        self.wrapped.WheelNumberOfTeeth = int(value) if value else 0

    @property
    def wheel_face_width(self) -> 'float':
        '''float: 'WheelFaceWidth' is the original name of this property.'''

        return self.wrapped.WheelFaceWidth

    @wheel_face_width.setter
    def wheel_face_width(self, value: 'float'):
        self.wrapped.WheelFaceWidth = float(value) if value else 0.0

    @property
    def module(self) -> 'float':
        '''float: 'Module' is the original name of this property.'''

        return self.wrapped.Module

    @module.setter
    def module(self, value: 'float'):
        self.wrapped.Module = float(value) if value else 0.0

    @property
    def wheel_mean_spiral_angle(self) -> 'float':
        '''float: 'WheelMeanSpiralAngle' is the original name of this property.'''

        return self.wrapped.WheelMeanSpiralAngle

    @wheel_mean_spiral_angle.setter
    def wheel_mean_spiral_angle(self, value: 'float'):
        self.wrapped.WheelMeanSpiralAngle = float(value) if value else 0.0

    @property
    def lead_angle_on_cutter_head(self) -> 'float':
        '''float: 'LeadAngleOnCutterHead' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LeadAngleOnCutterHead

    @property
    def machine_distance(self) -> 'float':
        '''float: 'MachineDistance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MachineDistance

    @property
    def base_circle_radius(self) -> 'float':
        '''float: 'BaseCircleRadius' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BaseCircleRadius

    @property
    def auxiliary_angle_at_re(self) -> 'float':
        '''float: 'AuxiliaryAngleAtRe' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AuxiliaryAngleAtRe

    @property
    def auxiliary_angle_at_ri(self) -> 'float':
        '''float: 'AuxiliaryAngleAtRi' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AuxiliaryAngleAtRi

    @property
    def spiral_angle_at_wheel_outer_diameter(self) -> 'float':
        '''float: 'SpiralAngleAtWheelOuterDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SpiralAngleAtWheelOuterDiameter

    @property
    def spiral_angle_at_wheel_inner_diameter(self) -> 'float':
        '''float: 'SpiralAngleAtWheelInnerDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SpiralAngleAtWheelInnerDiameter

    @property
    def normal_module_at_outer_diameter(self) -> 'float':
        '''float: 'NormalModuleAtOuterDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalModuleAtOuterDiameter

    @property
    def normal_module_at_inner_diameter(self) -> 'float':
        '''float: 'NormalModuleAtInnerDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalModuleAtInnerDiameter

    @property
    def cone_distance_maximum_tooth_gap(self) -> 'float':
        '''float: 'ConeDistanceMaximumToothGap' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ConeDistanceMaximumToothGap

    @property
    def addendum_of_tool(self) -> 'float':
        '''float: 'AddendumOfTool' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AddendumOfTool

    @property
    def cutter_blade_tip_width_causes_cut_off(self) -> 'bool':
        '''bool: 'CutterBladeTipWidthCausesCutOff' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CutterBladeTipWidthCausesCutOff

    @property
    def cutter_blade_tip_width_causes_ridge(self) -> 'bool':
        '''bool: 'CutterBladeTipWidthCausesRidge' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CutterBladeTipWidthCausesRidge

    @property
    def use_minimum_addendum_modification_factor(self) -> 'bool':
        '''bool: 'UseMinimumAddendumModificationFactor' is the original name of this property.'''

        return self.wrapped.UseMinimumAddendumModificationFactor

    @use_minimum_addendum_modification_factor.setter
    def use_minimum_addendum_modification_factor(self, value: 'bool'):
        self.wrapped.UseMinimumAddendumModificationFactor = bool(value) if value else False

    @property
    def whole_depth(self) -> 'float':
        '''float: 'WholeDepth' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WholeDepth

    @property
    def pinion_generating_cone_angle(self) -> 'float':
        '''float: 'PinionGeneratingConeAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionGeneratingConeAngle

    @property
    def wheel_generating_cone_angle(self) -> 'float':
        '''float: 'WheelGeneratingConeAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelGeneratingConeAngle

    @property
    def auxiliary_value_for_angle_modification(self) -> 'float':
        '''float: 'AuxiliaryValueForAngleModification' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AuxiliaryValueForAngleModification

    @property
    def tip_circle_diameter_of_virtual_gear(self) -> 'float':
        '''float: 'TipCircleDiameterOfVirtualGear' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TipCircleDiameterOfVirtualGear

    @property
    def normal_pressure_angle_at_tooth_tip(self) -> 'float':
        '''float: 'NormalPressureAngleAtToothTip' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalPressureAngleAtToothTip

    @property
    def tooth_thickness_half_angle_on_pitch_cone(self) -> 'float':
        '''float: 'ToothThicknessHalfAngleOnPitchCone' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToothThicknessHalfAngleOnPitchCone

    @property
    def tooth_thickness_half_angle_on_tooth_tip(self) -> 'float':
        '''float: 'ToothThicknessHalfAngleOnToothTip' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToothThicknessHalfAngleOnToothTip

    @property
    def tooth_tip_thickness_at_inner(self) -> 'float':
        '''float: 'ToothTipThicknessAtInner' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToothTipThicknessAtInner

    @property
    def tooth_tip_chamfering_factor(self) -> 'float':
        '''float: 'ToothTipChamferingFactor' is the original name of this property.'''

        return self.wrapped.ToothTipChamferingFactor

    @tooth_tip_chamfering_factor.setter
    def tooth_tip_chamfering_factor(self, value: 'float'):
        self.wrapped.ToothTipChamferingFactor = float(value) if value else 0.0

    @property
    def use_required_tooth_tip_chamfering_factor(self) -> 'bool':
        '''bool: 'UseRequiredToothTipChamferingFactor' is the original name of this property.'''

        return self.wrapped.UseRequiredToothTipChamferingFactor

    @use_required_tooth_tip_chamfering_factor.setter
    def use_required_tooth_tip_chamfering_factor(self, value: 'bool'):
        self.wrapped.UseRequiredToothTipChamferingFactor = bool(value) if value else False

    @property
    def tooth_tip_thickness_at_mean_cone_distance(self) -> 'float':
        '''float: 'ToothTipThicknessAtMeanConeDistance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToothTipThicknessAtMeanConeDistance

    @property
    def tip_cone_angle_from_tooth_tip_chamfering_reduction(self) -> 'float':
        '''float: 'TipConeAngleFromToothTipChamferingReduction' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TipConeAngleFromToothTipChamferingReduction

    @property
    def auxilliary_angle_at_re_2(self) -> 'float':
        '''float: 'AuxilliaryAngleAtRe2' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AuxilliaryAngleAtRe2

    @property
    def auxilliary_angle_at_ri_2(self) -> 'float':
        '''float: 'AuxilliaryAngleAtRi2' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AuxilliaryAngleAtRi2

    @property
    def face_contact_ratio(self) -> 'float':
        '''float: 'FaceContactRatio' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FaceContactRatio

    @property
    def gear_finish(self) -> '_1097.KlingelnbergFinishingMethods':
        '''KlingelnbergFinishingMethods: 'GearFinish' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.GearFinish)
        return constructor.new(_1097.KlingelnbergFinishingMethods)(value) if value else None

    @gear_finish.setter
    def gear_finish(self, value: '_1097.KlingelnbergFinishingMethods'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.GearFinish = value

    @property
    def effective_face_width(self) -> 'float':
        '''float: 'EffectiveFaceWidth' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EffectiveFaceWidth

    @property
    def gear_cutting_machine_options(self) -> 'list_with_selected_item.ListWithSelectedItem_str':
        '''list_with_selected_item.ListWithSelectedItem_str: 'GearCuttingMachineOptions' is the original name of this property.'''

        return constructor.new(list_with_selected_item.ListWithSelectedItem_str)(self.wrapped.GearCuttingMachineOptions) if self.wrapped.GearCuttingMachineOptions else None

    @gear_cutting_machine_options.setter
    def gear_cutting_machine_options(self, value: 'list_with_selected_item.ListWithSelectedItem_str.implicit_type()'):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_str.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_str.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else None)
        self.wrapped.GearCuttingMachineOptions = value

    @property
    def cutter_radius(self) -> 'float':
        '''float: 'CutterRadius' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CutterRadius

    @property
    def cutter_module(self) -> 'float':
        '''float: 'CutterModule' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CutterModule

    @property
    def number_of_starts(self) -> 'float':
        '''float: 'NumberOfStarts' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NumberOfStarts

    @property
    def conical_meshes(self) -> 'List[_920.KlingelnbergConicalGearMeshDesign]':
        '''List[KlingelnbergConicalGearMeshDesign]: 'ConicalMeshes' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConicalMeshes, constructor.new(_920.KlingelnbergConicalGearMeshDesign))
        return value

    @property
    def klingelnberg_conical_meshes(self) -> 'List[_920.KlingelnbergConicalGearMeshDesign]':
        '''List[KlingelnbergConicalGearMeshDesign]: 'KlingelnbergConicalMeshes' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergConicalMeshes, constructor.new(_920.KlingelnbergConicalGearMeshDesign))
        return value



'''_1675.py

LoadedBearingTemperatureChart
'''


from mastapy._internal import constructor
from mastapy.utility.report import _1510
from mastapy._internal.python_net import python_net_import

_LOADED_BEARING_TEMPERATURE_CHART = python_net_import('SMT.MastaAPI.Bearings.BearingResults', 'LoadedBearingTemperatureChart')


__docformat__ = 'restructuredtext en'
__all__ = ('LoadedBearingTemperatureChart',)


class LoadedBearingTemperatureChart(_1510.CustomReportChart):
    '''LoadedBearingTemperatureChart

    This is a mastapy class.
    '''

    TYPE = _LOADED_BEARING_TEMPERATURE_CHART

    __hash__ = None

    def __init__(self, instance_to_wrap: 'LoadedBearingTemperatureChart.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def number_of_steps(self) -> 'int':
        '''int: 'NumberOfSteps' is the original name of this property.'''

        return self.wrapped.NumberOfSteps

    @number_of_steps.setter
    def number_of_steps(self, value: 'int'):
        self.wrapped.NumberOfSteps = int(value) if value else 0

    @property
    def minimum_temperature(self) -> 'float':
        '''float: 'MinimumTemperature' is the original name of this property.'''

        return self.wrapped.MinimumTemperature

    @minimum_temperature.setter
    def minimum_temperature(self, value: 'float'):
        self.wrapped.MinimumTemperature = float(value) if value else 0.0

    @property
    def maximum_temperature(self) -> 'float':
        '''float: 'MaximumTemperature' is the original name of this property.'''

        return self.wrapped.MaximumTemperature

    @maximum_temperature.setter
    def maximum_temperature(self, value: 'float'):
        self.wrapped.MaximumTemperature = float(value) if value else 0.0



'''_1103.py

ConicalGearLeadModification
'''


from mastapy.gears.micro_geometry import _524
from mastapy._internal.python_net import python_net_import

_CONICAL_GEAR_LEAD_MODIFICATION = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Conical.MicroGeometry', 'ConicalGearLeadModification')


__docformat__ = 'restructuredtext en'
__all__ = ('ConicalGearLeadModification',)


class ConicalGearLeadModification(_524.LeadModification):
    '''ConicalGearLeadModification

    This is a mastapy class.
    '''

    TYPE = _CONICAL_GEAR_LEAD_MODIFICATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConicalGearLeadModification.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_4434.py

ConicalGearSetCompoundModalAnalysisAtAStiffness
'''


from typing import List

from mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness import _4304
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound import _4460
from mastapy._internal.python_net import python_net_import

_CONICAL_GEAR_SET_COMPOUND_MODAL_ANALYSIS_AT_A_STIFFNESS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtAStiffness.Compound', 'ConicalGearSetCompoundModalAnalysisAtAStiffness')


__docformat__ = 'restructuredtext en'
__all__ = ('ConicalGearSetCompoundModalAnalysisAtAStiffness',)


class ConicalGearSetCompoundModalAnalysisAtAStiffness(_4460.GearSetCompoundModalAnalysisAtAStiffness):
    '''ConicalGearSetCompoundModalAnalysisAtAStiffness

    This is a mastapy class.
    '''

    TYPE = _CONICAL_GEAR_SET_COMPOUND_MODAL_ANALYSIS_AT_A_STIFFNESS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConicalGearSetCompoundModalAnalysisAtAStiffness.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_analysis_cases(self) -> 'List[_4304.ConicalGearSetModalAnalysisAtAStiffness]':
        '''List[ConicalGearSetModalAnalysisAtAStiffness]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCases, constructor.new(_4304.ConicalGearSetModalAnalysisAtAStiffness))
        return value

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_4304.ConicalGearSetModalAnalysisAtAStiffness]':
        '''List[ConicalGearSetModalAnalysisAtAStiffness]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCasesReady, constructor.new(_4304.ConicalGearSetModalAnalysisAtAStiffness))
        return value



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._5629 import AbstractAssemblyHarmonicAnalysis
    from ._5630 import AbstractPeriodicExcitationDetail
    from ._5631 import AbstractShaftHarmonicAnalysis
    from ._5632 import AbstractShaftOrHousingHarmonicAnalysis
    from ._5633 import AbstractShaftToMountableComponentConnectionHarmonicAnalysis
    from ._5634 import AGMAGleasonConicalGearHarmonicAnalysis
    from ._5635 import AGMAGleasonConicalGearMeshHarmonicAnalysis
    from ._5636 import AGMAGleasonConicalGearSetHarmonicAnalysis
    from ._5637 import AssemblyHarmonicAnalysis
    from ._5638 import BearingHarmonicAnalysis
    from ._5639 import BeltConnectionHarmonicAnalysis
    from ._5640 import BeltDriveHarmonicAnalysis
    from ._5641 import BevelDifferentialGearHarmonicAnalysis
    from ._5642 import BevelDifferentialGearMeshHarmonicAnalysis
    from ._5643 import BevelDifferentialGearSetHarmonicAnalysis
    from ._5644 import BevelDifferentialPlanetGearHarmonicAnalysis
    from ._5645 import BevelDifferentialSunGearHarmonicAnalysis
    from ._5646 import BevelGearHarmonicAnalysis
    from ._5647 import BevelGearMeshHarmonicAnalysis
    from ._5648 import BevelGearSetHarmonicAnalysis
    from ._5649 import BoltedJointHarmonicAnalysis
    from ._5650 import BoltHarmonicAnalysis
    from ._5651 import ClutchConnectionHarmonicAnalysis
    from ._5652 import ClutchHalfHarmonicAnalysis
    from ._5653 import ClutchHarmonicAnalysis
    from ._5654 import CoaxialConnectionHarmonicAnalysis
    from ._5655 import ComplianceAndForceData
    from ._5656 import ComponentHarmonicAnalysis
    from ._5657 import ConceptCouplingConnectionHarmonicAnalysis
    from ._5658 import ConceptCouplingHalfHarmonicAnalysis
    from ._5659 import ConceptCouplingHarmonicAnalysis
    from ._5660 import ConceptGearHarmonicAnalysis
    from ._5661 import ConceptGearMeshHarmonicAnalysis
    from ._5662 import ConceptGearSetHarmonicAnalysis
    from ._5663 import ConicalGearHarmonicAnalysis
    from ._5664 import ConicalGearMeshHarmonicAnalysis
    from ._5665 import ConicalGearSetHarmonicAnalysis
    from ._5666 import ConnectionHarmonicAnalysis
    from ._5667 import ConnectorHarmonicAnalysis
    from ._5668 import CouplingConnectionHarmonicAnalysis
    from ._5669 import CouplingHalfHarmonicAnalysis
    from ._5670 import CouplingHarmonicAnalysis
    from ._5671 import CVTBeltConnectionHarmonicAnalysis
    from ._5672 import CVTHarmonicAnalysis
    from ._5673 import CVTPulleyHarmonicAnalysis
    from ._5674 import CycloidalAssemblyHarmonicAnalysis
    from ._5675 import CycloidalDiscCentralBearingConnectionHarmonicAnalysis
    from ._5676 import CycloidalDiscHarmonicAnalysis
    from ._5677 import CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysis
    from ._5678 import CylindricalGearHarmonicAnalysis
    from ._5679 import CylindricalGearMeshHarmonicAnalysis
    from ._5680 import CylindricalGearSetHarmonicAnalysis
    from ._5681 import CylindricalPlanetGearHarmonicAnalysis
    from ._5682 import DatumHarmonicAnalysis
    from ._2335 import DynamicModelForHarmonicAnalysis
    from ._5683 import ElectricMachinePeriodicExcitationDetail
    from ._5684 import ElectricMachineRotorXForcePeriodicExcitationDetail
    from ._5685 import ElectricMachineRotorXMomentPeriodicExcitationDetail
    from ._5686 import ElectricMachineRotorYForcePeriodicExcitationDetail
    from ._5687 import ElectricMachineRotorYMomentPeriodicExcitationDetail
    from ._5688 import ElectricMachineRotorZForcePeriodicExcitationDetail
    from ._5689 import ElectricMachineStatorToothAxialLoadsExcitationDetail
    from ._5690 import ElectricMachineStatorToothLoadsExcitationDetail
    from ._5691 import ElectricMachineStatorToothRadialLoadsExcitationDetail
    from ._5692 import ElectricMachineStatorToothTangentialLoadsExcitationDetail
    from ._5693 import ElectricMachineTorqueRipplePeriodicExcitationDetail
    from ._5694 import ExportOutputType
    from ._5695 import ExternalCADModelHarmonicAnalysis
    from ._5696 import FaceGearHarmonicAnalysis
    from ._5697 import FaceGearMeshHarmonicAnalysis
    from ._5698 import FaceGearSetHarmonicAnalysis
    from ._5699 import FEPartHarmonicAnalysis
    from ._5700 import FlexiblePinAssemblyHarmonicAnalysis
    from ._5701 import FrequencyOptionsForHarmonicAnalysisResults
    from ._5702 import GearHarmonicAnalysis
    from ._5703 import GearMeshExcitationDetail
    from ._5704 import GearMeshHarmonicAnalysis
    from ._5705 import GearMeshMisalignmentExcitationDetail
    from ._5706 import GearMeshTEExcitationDetail
    from ._5707 import GearSetHarmonicAnalysis
    from ._5708 import GeneralPeriodicExcitationDetail
    from ._5709 import GuideDxfModelHarmonicAnalysis
    from ._2339 import HarmonicAnalysis
    from ._5710 import HarmonicAnalysisDrawStyle
    from ._5711 import HarmonicAnalysisExportOptions
    from ._5712 import HarmonicAnalysisFEExportOptions
    from ._2340 import HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation
    from ._5713 import HarmonicAnalysisOptions
    from ._5714 import HarmonicAnalysisRootAssemblyExportOptions
    from ._5715 import HarmonicAnalysisShaftExportOptions
    from ._5716 import HypoidGearHarmonicAnalysis
    from ._5717 import HypoidGearMeshHarmonicAnalysis
    from ._5718 import HypoidGearSetHarmonicAnalysis
    from ._5719 import InterMountableComponentConnectionHarmonicAnalysis
    from ._5720 import KlingelnbergCycloPalloidConicalGearHarmonicAnalysis
    from ._5721 import KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysis
    from ._5722 import KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysis
    from ._5723 import KlingelnbergCycloPalloidHypoidGearHarmonicAnalysis
    from ._5724 import KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis
    from ._5725 import KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysis
    from ._5726 import KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysis
    from ._5727 import KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysis
    from ._5728 import KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysis
    from ._5729 import MassDiscHarmonicAnalysis
    from ._5730 import MeasurementComponentHarmonicAnalysis
    from ._5731 import MountableComponentHarmonicAnalysis
    from ._5732 import OilSealHarmonicAnalysis
    from ._5733 import PartHarmonicAnalysis
    from ._5734 import PartToPartShearCouplingConnectionHarmonicAnalysis
    from ._5735 import PartToPartShearCouplingHalfHarmonicAnalysis
    from ._5736 import PartToPartShearCouplingHarmonicAnalysis
    from ._5737 import PeriodicExcitationWithReferenceShaft
    from ._5738 import PlanetaryConnectionHarmonicAnalysis
    from ._5739 import PlanetaryGearSetHarmonicAnalysis
    from ._5740 import PlanetCarrierHarmonicAnalysis
    from ._5741 import PointLoadHarmonicAnalysis
    from ._5742 import PowerLoadHarmonicAnalysis
    from ._5743 import PulleyHarmonicAnalysis
    from ._5744 import RingPinsHarmonicAnalysis
    from ._5745 import RingPinsToDiscConnectionHarmonicAnalysis
    from ._5746 import RollingRingAssemblyHarmonicAnalysis
    from ._5747 import RollingRingConnectionHarmonicAnalysis
    from ._5748 import RollingRingHarmonicAnalysis
    from ._5749 import RootAssemblyHarmonicAnalysis
    from ._5750 import ShaftHarmonicAnalysis
    from ._5751 import ShaftHubConnectionHarmonicAnalysis
    from ._5752 import ShaftToMountableComponentConnectionHarmonicAnalysis
    from ._5753 import SingleNodePeriodicExcitationWithReferenceShaft
    from ._5754 import SpecialisedAssemblyHarmonicAnalysis
    from ._5755 import SpeedOptionsForHarmonicAnalysisResults
    from ._5756 import SpiralBevelGearHarmonicAnalysis
    from ._5757 import SpiralBevelGearMeshHarmonicAnalysis
    from ._5758 import SpiralBevelGearSetHarmonicAnalysis
    from ._5759 import SpringDamperConnectionHarmonicAnalysis
    from ._5760 import SpringDamperHalfHarmonicAnalysis
    from ._5761 import SpringDamperHarmonicAnalysis
    from ._5762 import StraightBevelDiffGearHarmonicAnalysis
    from ._5763 import StraightBevelDiffGearMeshHarmonicAnalysis
    from ._5764 import StraightBevelDiffGearSetHarmonicAnalysis
    from ._5765 import StraightBevelGearHarmonicAnalysis
    from ._5766 import StraightBevelGearMeshHarmonicAnalysis
    from ._5767 import StraightBevelGearSetHarmonicAnalysis
    from ._5768 import StraightBevelPlanetGearHarmonicAnalysis
    from ._5769 import StraightBevelSunGearHarmonicAnalysis
    from ._5770 import SynchroniserHalfHarmonicAnalysis
    from ._5771 import SynchroniserHarmonicAnalysis
    from ._5772 import SynchroniserPartHarmonicAnalysis
    from ._5773 import SynchroniserSleeveHarmonicAnalysis
    from ._5774 import TorqueConverterConnectionHarmonicAnalysis
    from ._5775 import TorqueConverterHarmonicAnalysis
    from ._5776 import TorqueConverterPumpHarmonicAnalysis
    from ._5777 import TorqueConverterTurbineHarmonicAnalysis
    from ._5778 import UnbalancedMassExcitationDetail
    from ._5779 import UnbalancedMassHarmonicAnalysis
    from ._5780 import VirtualComponentHarmonicAnalysis
    from ._5781 import WormGearHarmonicAnalysis
    from ._5782 import WormGearMeshHarmonicAnalysis
    from ._5783 import WormGearSetHarmonicAnalysis
    from ._5784 import ZerolBevelGearHarmonicAnalysis
    from ._5785 import ZerolBevelGearMeshHarmonicAnalysis
    from ._5786 import ZerolBevelGearSetHarmonicAnalysis



'''_1128.py

GearMeshingElementOptions
'''


from typing import List

from mastapy._internal import constructor, conversion
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_GEAR_MESHING_ELEMENT_OPTIONS = python_net_import('SMT.MastaAPI.Gears.FEModel', 'GearMeshingElementOptions')


__docformat__ = 'restructuredtext en'
__all__ = ('GearMeshingElementOptions',)


class GearMeshingElementOptions(_0.APIBase):
    '''GearMeshingElementOptions

    This is a mastapy class.
    '''

    TYPE = _GEAR_MESHING_ELEMENT_OPTIONS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GearMeshingElementOptions.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def face_elements(self) -> 'int':
        '''int: 'FaceElements' is the original name of this property.'''

        return self.wrapped.FaceElements

    @face_elements.setter
    def face_elements(self, value: 'int'):
        self.wrapped.FaceElements = int(value) if value else 0

    @property
    def profile_elements(self) -> 'int':
        '''int: 'ProfileElements' is the original name of this property.'''

        return self.wrapped.ProfileElements

    @profile_elements.setter
    def profile_elements(self, value: 'int'):
        self.wrapped.ProfileElements = int(value) if value else 0

    @property
    def fillet_elements(self) -> 'int':
        '''int: 'FilletElements' is the original name of this property.'''

        return self.wrapped.FilletElements

    @fillet_elements.setter
    def fillet_elements(self, value: 'int'):
        self.wrapped.FilletElements = int(value) if value else 0

    @property
    def tip_elements(self) -> 'int':
        '''int: 'TipElements' is the original name of this property.'''

        return self.wrapped.TipElements

    @tip_elements.setter
    def tip_elements(self, value: 'int'):
        self.wrapped.TipElements = int(value) if value else 0

    @property
    def body_elements(self) -> 'overridable.Overridable_int':
        '''overridable.Overridable_int: 'BodyElements' is the original name of this property.'''

        return constructor.new(overridable.Overridable_int)(self.wrapped.BodyElements) if self.wrapped.BodyElements else None

    @body_elements.setter
    def body_elements(self, value: 'overridable.Overridable_int.implicit_type()'):
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0, is_overridden)
        self.wrapped.BodyElements = value

    @property
    def radial_elements(self) -> 'int':
        '''int: 'RadialElements' is the original name of this property.'''

        return self.wrapped.RadialElements

    @radial_elements.setter
    def radial_elements(self, value: 'int'):
        self.wrapped.RadialElements = int(value) if value else 0

    @property
    def web_elements(self) -> 'overridable.Overridable_int':
        '''overridable.Overridable_int: 'WebElements' is the original name of this property.'''

        return constructor.new(overridable.Overridable_int)(self.wrapped.WebElements) if self.wrapped.WebElements else None

    @web_elements.setter
    def web_elements(self, value: 'overridable.Overridable_int.implicit_type()'):
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0, is_overridden)
        self.wrapped.WebElements = value

    @property
    def rim_elements(self) -> 'overridable.Overridable_int':
        '''overridable.Overridable_int: 'RimElements' is the original name of this property.'''

        return constructor.new(overridable.Overridable_int)(self.wrapped.RimElements) if self.wrapped.RimElements else None

    @rim_elements.setter
    def rim_elements(self, value: 'overridable.Overridable_int.implicit_type()'):
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0, is_overridden)
        self.wrapped.RimElements = value

    @property
    def report_names(self) -> 'List[str]':
        '''List[str]: 'ReportNames' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ReportNames, str)
        return value

    def output_default_report_to(self, file_path: 'str'):
        ''' 'OutputDefaultReportTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else None)

    def get_default_report_with_encoded_images(self) -> 'str':
        ''' 'GetDefaultReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        '''

        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    def output_active_report_to(self, file_path: 'str'):
        ''' 'OutputActiveReportTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else None)

    def output_active_report_as_text_to(self, file_path: 'str'):
        ''' 'OutputActiveReportAsTextTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else None)

    def get_active_report_with_encoded_images(self) -> 'str':
        ''' 'GetActiveReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        '''

        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    def output_named_report_to(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(report_name if report_name else None, file_path if file_path else None)

    def output_named_report_as_masta_report(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportAsMastaReport' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(report_name if report_name else None, file_path if file_path else None)

    def output_named_report_as_text_to(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportAsTextTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(report_name if report_name else None, file_path if file_path else None)

    def get_named_report_with_encoded_images(self, report_name: 'str') -> 'str':
        ''' 'GetNamedReportWithEncodedImages' is the original name of this method.

        Args:
            report_name (str)

        Returns:
            str
        '''

        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(report_name if report_name else None)
        return method_result



'''_1058.py

ProfileSlopeReliefWithDeviation
'''


from mastapy._internal import constructor
from mastapy.gears.gear_designs.cylindrical.micro_geometry import _1057
from mastapy._internal.python_net import python_net_import

_PROFILE_SLOPE_RELIEF_WITH_DEVIATION = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical.MicroGeometry', 'ProfileSlopeReliefWithDeviation')


__docformat__ = 'restructuredtext en'
__all__ = ('ProfileSlopeReliefWithDeviation',)


class ProfileSlopeReliefWithDeviation(_1057.ProfileReliefWithDeviation):
    '''ProfileSlopeReliefWithDeviation

    This is a mastapy class.
    '''

    TYPE = _PROFILE_SLOPE_RELIEF_WITH_DEVIATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ProfileSlopeReliefWithDeviation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def face_width(self) -> 'float':
        '''float: 'FaceWidth' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FaceWidth
